@@ -109,12 +109,13 @@ int size, increment, dimension, offset; } gamgi_darray;
 
 typedef struct _gamgi_object {
 char name[GAMGI_ENGINE_TOKEN];
-char type[GAMGI_ENGINE_TOKEN];
+char label[GAMGI_ENGINE_TOKEN];
 unsigned int number;
 int class;
 double scale;
 struct _gamgi_object *object; 
-gamgi_dlist *dlist; } gamgi_object;
+gamgi_dlist *dlist;
+gamgi_dlist *selection; } gamgi_object;
 
 /******** 
  * text *
@@ -289,11 +290,16 @@ typedef struct _gamgi_group {
 gamgi_object object;
 void (*draw) (struct _gamgi_group *);
 
-gamgi_bool faces;
+gamgi_enum type;
+int atom, element, number;
+double visible, coplanar; 
+gamgi_enum autonomy;
 
 double origin[3], center[3];
 double quaternion[4];
 
+gamgi_bool faces;
+
 double *points;
 int *loops;
 int n_points, n_loops;
@@ -350,7 +356,7 @@ struct _gamgi_molecule *next, *before; } gamgi_molecule;
 typedef struct _gamgi_cluster {
 gamgi_object object;
 
-gamgi_bool faces, seeds;
+gamgi_bool faces, dots;
 
 double origin[3], center[3];
 double quaternion[4];
@@ -362,7 +368,7 @@ int *paints;
 
 int n_points, n_loops;
 int n_colors, n_paints;
-int n_seeds;
+int n_dots;
 
 gamgi_dlist *text_start;
 gamgi_dlist *text_end;
@@ -655,11 +661,16 @@ GtkWidget *help;
 gamgi_dlist *history;
 gamgi_layer *layer;
 gamgi_object *focus;
+
 gamgi_enum action;
 gamgi_enum mode;
-gamgi_enum selection;
+gamgi_enum class;
 gamgi_bool axes;
 
+/*********************
+ * window dimensions *
+ *********************/
+
 int origin_x, origin_y;
 int width, height;
 
@@ -670,9 +681,9 @@ int width, height;
 GtkWidget *top;
 GtkWidget *medium;
 GtkWidget *bottom;
+gamgi_bool top_flag;
 gamgi_bool medium_flag;
 gamgi_bool bottom_flag;
-gamgi_bool top_flag;
 
 /*******************
  * graphic section *
