@@ -826,13 +826,6 @@ gamgi_mesa_text_font_start ();
 gamgi->message = NULL;
 gamgi->question = NULL;
 
-/********************************
- * initialize gtkglext pointers *
- ********************************/
-
-gamgi->glconfig = NULL;
-gamgi->glcontext = NULL;
-
 /**************************************
  * create configuration class objects *
  **************************************/
