@@ -21,6 +21,7 @@
 #include "gamgi_gtk_history.h"
 #include "gamgi_mesa_text.h"
 #include "gamgi_math_hash.h"
+#include "gamgi_global_selection.h"
 #include "gamgi_global_remove.h"
 
 /***************** external function *********************
@@ -37,6 +38,13 @@ void gamgi_engine_remove_text (gamgi_text *text)
 gamgi_dlist *dlist;
 gamgi_text *text_next, *text_before;
 
+/********************************
+ * remove text global selection *
+ ********************************/
+
+gamgi_global_selection_clean (&gamgi->texts,
+text->object.selection, "button_text");
+
 /********************
  * remove text list *
  ********************/
@@ -90,6 +98,13 @@ void gamgi_engine_remove_orbital (gamgi_orbital *orbital)
 gamgi_dlist *dlist;
 gamgi_orbital *orbital_next, *orbital_before;
 
+/***********************************
+ * remove orbital global selection *
+ ***********************************/
+
+gamgi_global_selection_clean (&gamgi->orbitals,
+orbital->object.selection, "button_orbital");
+
 /********************
  * remove text list *
  ********************/
@@ -128,6 +143,13 @@ void gamgi_engine_remove_bond (gamgi_bond *bond)
 gamgi_dlist *dlist;
 gamgi_bond *bond_next, *bond_before;
 
+/********************************
+ * remove bond global selection *
+ ********************************/
+
+gamgi_global_selection_clean (&gamgi->bonds,
+bond->object.selection, "button_bond");
+
 /********************
  * remove text list *
  ********************/
@@ -174,6 +196,13 @@ gamgi_dlist *dlist;
 gamgi_atom *atom_next, *atom_before;
 gamgi_bond *bond;
 
+/********************************
+ * remove atom global selection *
+ ********************************/
+
+gamgi_global_selection_clean (&gamgi->atoms,
+atom->object.selection, "button_atom");
+
 /********************
  * remove text list *
  ********************/
@@ -230,6 +259,13 @@ void gamgi_engine_remove_direction (gamgi_direction *direction)
 gamgi_dlist *dlist;
 gamgi_direction *direction_next, *direction_before;
 
+/*************************************
+ * remove direction global selection *
+ *************************************/
+
+gamgi_global_selection_clean (&gamgi->directions,
+direction->object.selection, "button_direction");
+
 /********************
  * remove text list *
  ********************/
@@ -291,6 +327,13 @@ void gamgi_engine_remove_plane (gamgi_plane *plane)
 gamgi_dlist *dlist;
 gamgi_plane *plane_next, *plane_before;
 
+/********************************
+ * remove plane global selection *
+ ********************************/
+
+gamgi_global_selection_clean (&gamgi->planes,
+plane->object.selection, "button_plane");
+
 /********************
  * remove text list *
  ********************/
@@ -362,6 +405,13 @@ void gamgi_engine_remove_group (gamgi_group *group)
 gamgi_dlist *dlist;
 gamgi_group *group_next, *group_before;
 
+/*********************************
+ * remove group global selection *
+ *********************************/
+
+gamgi_global_selection_clean (&gamgi->groups,
+group->object.selection, "button_group");
+
 /********************
  * remove text list *
  ********************/
@@ -450,6 +500,13 @@ void gamgi_engine_remove_molecule (gamgi_molecule *molecule)
 gamgi_dlist *dlist;
 gamgi_molecule *molecule_next, *molecule_before;
 
+/************************************
+ * remove molecule global selection *
+ ************************************/
+
+gamgi_global_selection_clean (&gamgi->molecules,
+molecule->object.selection, "button_molecule");
+
 /********************
  * remove text list *
  ********************/
@@ -535,6 +592,13 @@ void gamgi_engine_remove_cluster (gamgi_cluster *cluster)
 gamgi_dlist *dlist;
 gamgi_cluster *cluster_next, *cluster_before; 
 
+/***********************************
+ * remove cluster global selection *
+ ***********************************/
+
+gamgi_global_selection_clean (&gamgi->clusters,
+cluster->object.selection, "button_cluster");
+
 /********************
  * remove text list *
  ********************/
@@ -649,6 +713,13 @@ void gamgi_engine_remove_cell (gamgi_cell *cell)
 gamgi_dlist *dlist;
 gamgi_cell *cell_next, *cell_before;
 
+/********************************
+ * remove cell global selection *
+ ********************************/
+
+gamgi_global_selection_clean (&gamgi->cells,
+cell->object.selection, "button_cell");
+
 /********************
  * remove text list *
  ********************/
@@ -758,6 +829,13 @@ void gamgi_engine_remove_arrow (gamgi_arrow *arrow)
 gamgi_dlist *dlist;
 gamgi_arrow *arrow_next, *arrow_before;
 
+/*********************************
+ * remove arrow global selection *
+ *********************************/
+
+gamgi_global_selection_clean (&gamgi->arrows,
+arrow->object.selection, "button_arrow");
+
 /********************
  * remove text list *
  ********************/
@@ -794,6 +872,13 @@ void gamgi_engine_remove_shape (gamgi_shape *shape)
 gamgi_dlist *dlist;
 gamgi_shape *shape_next, *shape_before;
 
+/*********************************
+ * remove shape global selection *
+ *********************************/
+
+gamgi_global_selection_clean (&gamgi->shapes,
+shape->object.selection, "button_shape");
+
 /********************
  * remove text list *
  ********************/
@@ -830,6 +915,13 @@ void gamgi_engine_remove_graph (gamgi_graph *graph)
 gamgi_dlist *dlist;
 gamgi_graph *graph_next, *graph_before;
 
+/*********************************
+ * remove graph global selection *
+ *********************************/
+
+gamgi_global_selection_clean (&gamgi->graphs,
+graph->object.selection, "button_graph");
+
 /********************
  * remove text list *
  ********************/
@@ -867,6 +959,13 @@ void gamgi_engine_remove_assembly (gamgi_assembly *assembly)
 gamgi_dlist *dlist;
 gamgi_assembly *assembly_next, *assembly_before;
 
+/************************************
+ * remove assembly global selection *
+ ************************************/
+
+gamgi_global_selection_clean (&gamgi->assemblys,
+assembly->object.selection, "button_assembly");
+
 /********************
  * remove text list *
  ********************/
@@ -1017,6 +1116,13 @@ void gamgi_engine_remove_light (gamgi_light *light)
 {
 gamgi_light *light_next, *light_before;
 
+/*********************************
+ * remove light global selection *
+ *********************************/
+
+gamgi_global_selection_clean (&gamgi->lights,
+light->object.selection, "button_light");
+
 /****************
  * remove light *
  ****************/
@@ -1044,9 +1150,20 @@ void gamgi_engine_remove_layer (gamgi_layer *layer)
 gamgi_dlist *dlist;
 gamgi_layer *layer_next, *layer_before;
 
+/**************************************
+ * clean Undo,Save history mechanisms *
+ **************************************/
+
 if (layer->undo != NULL) gamgi_gtk_history_layer_reset (layer->undo);
 if (layer->save != NULL) gamgi_gtk_history_layer_reset (layer->save);
 
+/*********************************
+ * remove layer global selection *
+ *********************************/
+
+gamgi_global_selection_clean (&gamgi->layers,
+layer->object.selection, "button_layer");
+
 /********************
  * remove text list *
  ********************/
@@ -1205,7 +1322,19 @@ void gamgi_engine_remove_window (gamgi_window *window)
 gamgi_dlist *dlist;
 gamgi_window *window_next, *window_before;
 
-if (window->history != NULL) gamgi_gtk_history_window_reset (window->history);
+/**************************************
+ * clean Undo,Save history mechanisms *
+ **************************************/
+
+if (window->history != NULL)
+  gamgi_gtk_history_window_reset (window->history);
+
+/**********************************
+ * remove window global selection *
+ **********************************/
+
+gamgi_global_selection_clean (&gamgi->windows,
+window->object.selection, "button_window");
 
 /*********************
  * remove layer list *
