@@ -187,13 +187,6 @@ int r, g, b;
 int max_lights;
 int timer_time;
 
-/*********************
- * GTKGLext pointers *
- *********************/
-
-GdkGLConfig *glconfig;
-GdkGLContext *glcontext;
-
 /*****************************
  * internal resources:       *
  * - message dialog address  *
