@@ -72,13 +72,15 @@ gamgi_layer *layer;
 
 gtk_disable_setlocale ();
 
-/*************************************************
- * Start GTK, GTKGLext: to know which version is *
- * running, use pkg-config --modversion gtk+-2.0 *
- *************************************************/
+/************************************
+ * Check if GTK is working properly *
+ ************************************/
 
-gtk_init (&argc, &argv);
-gtk_gl_init (&argc, &argv);
+if (gtk_init_check (&argc, &argv) == FALSE)
+  { fprintf (stderr, "Error: GTK not supported\n"); return 1; }
+
+if (gtk_gl_init_check (&argc, &argv) == FALSE)
+  { fprintf (stderr, "Error: OpenGL not supported\n"); return 1; }
 
 /***********************************************************
  * Start GAMGI engine, including all basic infra-structure *
@@ -128,9 +130,6 @@ layer->save->data = layer;
 /*********************************************
  *    link layer to window and show window   *
  *                                           *
- *      get GL context from first window,    *
- *      only AFTER the window is realized    *
- *                                           *
  * Add time timer to the status bar, updated *
  * every GAMGI_GTK_STATUSBAR_TIME_TIME secs  *
  *********************************************/
@@ -138,7 +137,8 @@ layer->save->data = layer;
 gamgi_engine_link_layer_window (layer, window);
 gamgi_gtk_window_create (window, layer);
 
-gamgi->glcontext = gtk_widget_get_gl_context (window->area);
+if (window->area == NULL)
+  { fprintf (stderr, "Error: OpenGL not supported\n"); return 1; }
 
 /**************************************************
  * Update the time in the status bar every 60 sec *
