@@ -13,6 +13,12 @@
  * external functions *
  **********************/
 
+void gamgi_global_selection_focus (void);
+
+void gamgi_global_selection_undo (void);
+
+void gamgi_global_selection_draw (void);
+
 void gamgi_global_selection_show (char *label);
 
 void gamgi_global_selection_hide (char *label);
