@@ -11,6 +11,7 @@
 
 #include "gamgi_engine.h"
 #include "gamgi_gtk.h"
+#include "gamgi_global.h"
 
 #include "gamgi_engine_list.h"
 #include "gamgi_engine_find.h"
@@ -22,6 +23,7 @@
 #include "gamgi_gtk_object.h"
 #include "gamgi_mesa_select.h"
 #include "gamgi_io_token.h"
+#include "gamgi_global_selection.h"
 
 static void static_clean (gamgi_window *window)
 {
@@ -63,15 +65,15 @@ combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 }
 
-/*********************** internal function ******************
- *                                                          *
- *                         STATIC_GLOBAL                    *
- *                                                          *
- * When the global button is on, disable the assembly entry *
- * and reset dialog, otherwise, enable the assembly entry.  *        
- ************************************************************/
+/*********************** internal function *****************
+ *                                                         *
+ *                         STATIC_LIST                     *
+ *                                                         *
+ * When the List button is on, disable the assembly entry  *
+ * and reset dialog, otherwise, enable the assembly entry. *
+ ***********************************************************/
 
-static void static_global (GtkWidget *widget, void *data)
+static void static_list (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
@@ -79,7 +81,7 @@ GtkWidget *hbox;
 GtkWidget *button;
 
 hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_assembly");
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   {
@@ -100,15 +102,13 @@ else
   }
 }
 
-static void static_apply (gamgi_assembly *assembly, gamgi_window *window)
+static void static_apply (gamgi_assembly *assembly, int scope,
+gamgi_window *window)
 {
 gamgi_atom *atom;
 gamgi_bond *bond;
 gamgi_object *parent;
 gamgi_dlist *dlist, *dlist_b;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *combo;
-int row;
 
 /******************************************************
  * Remove assembly data according to Scope combo box: *
@@ -119,14 +119,11 @@ int row;
  * 4) Child: Remove the child list of a given class;  *
  ******************************************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
 /*********************************************
  * All: remove assembly and all its contents *
  ********************************************/
 
-if (row == 0)
+if (scope == 0)
   {
   gamgi_engine_unlink_assembly (assembly);
   gamgi_engine_remove_assembly (assembly);
@@ -136,7 +133,7 @@ if (row == 0)
  * Container: link contents to assembly parent and remove assembly *
  *******************************************************************/
 
-if (row == 1)
+if (scope == 1)
   {
   parent = assembly->object.object;
   gamgi_engine_reparent_cell (assembly->assembly_start, parent);
@@ -157,7 +154,7 @@ if (row == 1)
  * Contents: remove all child objects in assembly *
  **************************************************/
 
-if (row == 2)
+if (scope == 2)
   {
   dlist = assembly->assembly_start;
   while (dlist != NULL)
@@ -234,7 +231,7 @@ if (row == 2)
  * Assembly: remove assembly list in assembly *
  **********************************************/
 
-if (row == 3)
+if (scope == 3)
   {
   dlist = assembly->assembly_start;
   while (dlist != NULL)
@@ -248,7 +245,7 @@ if (row == 3)
  * Cell: remove cell list in assembly *
  **************************************/
 
-if (row == 4)
+if (scope == 4)
   {
   dlist = assembly->cell_start;
   while (dlist != NULL)
@@ -262,7 +259,7 @@ if (row == 4)
  * Cluster: remove cluster list in assembly *
  ********************************************/
 
-if (row == 5)
+if (scope == 5)
   {
   dlist = assembly->cluster_start;
   while (dlist != NULL)
@@ -276,7 +273,7 @@ if (row == 5)
  * Molecule: remove molecule list in assembly *
  **********************************************/
 
-if (row == 6)
+if (scope == 6)
   {
   dlist = assembly->molecule_start;
   while (dlist != NULL)
@@ -290,7 +287,7 @@ if (row == 6)
  * Group: remove group list in assembly *
  ****************************************/
 
-if (row == 7)
+if (scope == 7)
   {
   dlist = assembly->group_start;
   while (dlist != NULL)
@@ -304,7 +301,7 @@ if (row == 7)
  * Plane: remove plane list in assembly *
  ****************************************/
 
-if (row == 8)
+if (scope == 8)
   {
   dlist = assembly->plane_start;
   while (dlist != NULL)
@@ -318,7 +315,7 @@ if (row == 8)
  * Direction: remove direction list in assembly *
  ************************************************/
 
-if (row == 9)
+if (scope == 9)
   {
   dlist = assembly->direction_start;
   while (dlist != NULL)
@@ -332,7 +329,7 @@ if (row == 9)
  * Atom: remove atom list in assembly *
  **************************************/
 
-if (row == 10)
+if (scope == 10)
   {
   dlist = assembly->atom_start;
   while (dlist != NULL)
@@ -346,7 +343,7 @@ if (row == 10)
  * Bond: remove bond list in atom list in assembly *
  ***************************************************/
 
-if (row == 11)
+if (scope == 11)
   {
   dlist = assembly->atom_start;
   while (dlist != NULL)
@@ -369,7 +366,7 @@ if (row == 11)
  * Orbital: remove orbital list in assembly *
  ********************************************/
 
-if (row == 12)
+if (scope == 12)
   {
   dlist = assembly->orbital_start;
   while (dlist != NULL)
@@ -383,7 +380,7 @@ if (row == 12)
  * Text: remove text list in assembly *
  **************************************/
 
-if (row == 13)
+if (scope == 13)
   {
   dlist = assembly->text_start;
   while (dlist != NULL)
@@ -395,57 +392,135 @@ if (row == 13)
 
 }
 
+static void static_ok_global (int scope, gamgi_window *window)
+{
+gamgi_dlist *dlist, *assemblys;
+
+if (gamgi->assemblys == NULL)
+  { gamgi_gtk_dialog_message_create ("Error",
+  "Empty list of assembly objects", window); return; }
+
+/************************************************
+ * for all windows: save layers as undo layers, *
+ * set current layer as new current object      *
+ ************************************************/
+
+gamgi_global_selection_undo ();
+gamgi_global_selection_focus ();
+
+/*********************************************************
+ * disable automatic mechanism to remove selection list, *
+ * so we can scan the list and remove it only in the end *
+ *********************************************************/
+
+assemblys = gamgi->assemblys;
+gamgi->assemblys = NULL;
+
+/**********************************************************
+ * remove assembly data as specified in scope combo box   *
+ *                                                        *
+ * assemblys are recursive objects: a assembly may        *
+ * recursively remove a child of the same class that      *
+ * appears later in the list: listed objects that were    *
+ * already removed will have a list node pointing to NULL *
+ **********************************************************/
+
+for (dlist = assemblys; dlist != NULL; dlist = dlist->next)
+  if (dlist->data != NULL)
+    static_apply (GAMGI_CAST_ASSEMBLY dlist->data, scope, window);
+
+/******************************************************
+ * remove the selection list of a class of objects    *
+ * only when objects of that class are really removed *
+ ******************************************************/
+
+gamgi->assemblys = assemblys;
+if (scope < 4)
+  gamgi_global_selection_remove (&gamgi->assemblys, "button_assembly");
+
+/*****************************************
+ * For all windows: redraw gl_area image *
+ *****************************************/
+
+gamgi_global_selection_draw ();
+}
+
+static void static_ok_local (int scope, gamgi_window *window)
+{
+gamgi_assembly *assembly;
+GtkWidget *dialog = window->dialog0;
+
+/***************
+ * Pick object *
+ ***************/
+
+assembly = GAMGI_CAST_ASSEMBLY gamgi_gtk_object_name_number (dialog,
+"entry_assembly", GAMGI_ENGINE_ASSEMBLY, window);
+if (assembly == NULL)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid assembly object", window);
+  return;
+  }
+
+/*************************************************
+ * Before removing the assembly, check if the    *
+ * current object is affected. In this case, the *
+ * current layer becomes the new current object. *
+ *************************************************/
+
+if (gamgi_engine_find_object (window->focus,
+GAMGI_CAST_OBJECT assembly) == TRUE)
+  gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
+
+/***************************************
+ * Save current layer as undo buffer   *
+ * layer so it can be recovered later. *
+ ***************************************/
+
+gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
+
+/*****************************************************
+ * remove assembly data as chosen in scope combo box *
+ *****************************************************/
+
+static_apply (assembly, scope, window);
+
+/*************************************************
+ * Redraw gl_area image and reset assembly entry *
+ *************************************************/
+
+gtk_widget_queue_draw (window->area);
+}
+
 static void static_ok (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
-gamgi_assembly *assembly;
 GtkWidget *dialog = window->dialog0;
 GtkWidget *button;
+GtkWidget *combo;
+int scope;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
-  {
-  /***************
-   * Pick method *
-   ***************/
+/*********************************************************
+ * get dialog data common to both local and global tasks *
+ *********************************************************/
 
-  assembly = GAMGI_CAST_ASSEMBLY gamgi_gtk_object_name_number (dialog,
-  "entry_assembly", GAMGI_ENGINE_ASSEMBLY, window);
-  if (assembly == NULL)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid assembly object", window);
-    return;
-    }
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
+scope = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
-  /*************************************************
-   * Before removing the assembly, check if the    *
-   * current object is affected. In this case, the *
-   * current layer becomes the new current object. *
-   *************************************************/
+/********************************
+ * execute global or local task *
+ ********************************/
 
-  if (gamgi_engine_find_object (window->focus, 
-  GAMGI_CAST_OBJECT assembly) == TRUE)
-    gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  static_ok_global (scope, window);
+else
+  static_ok_local (scope, window);
 
-  /***************************************
-   * Save current layer as undo buffer   *
-   * layer so it can be recovered later. *
-   ***************************************/
+/***********************************************************
+ * clean dialog data common to both local and global tasks *
+ ***********************************************************/
 
-  gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
-
-  /*****************************************************
-   * remove assembly data as chosen in scope combo box *
-   *****************************************************/
-
-  static_apply (assembly, window);
-  }
-
-/*********************************************
- * Redraw gl_area image and reset text entry *
- *********************************************/
-
-gtk_widget_queue_draw (window->area);
 static_clean (window);
 }
 
@@ -492,7 +567,7 @@ GtkWidget *button;
  * local mouse selection only *
  ******************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE ||
 window_dialog != window_mouse) return;
 
@@ -570,15 +645,15 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 g_object_set_data (G_OBJECT (dialog), "entry_assembly", entry);
 gtk_widget_show (entry);
 
-/**********
- * Global *
- **********/
+/********
+ * List *
+ ********/
 
-button = gtk_toggle_button_new_with_label ("Global");
+button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "toggled",
-G_CALLBACK (static_global), window);
-g_object_set_data (G_OBJECT (dialog), "button_global", button);
+G_CALLBACK (static_list), window);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /************
