@@ -31,16 +31,16 @@
 #include "gamgi_chem_atom.h"
 #include "gamgi_io_token.h"
 
-static void static_name (GtkWidget *widget, void *data);
+static void static_element (GtkWidget *widget, void *data);
 static void static_number (GtkWidget *widget, void *data);
 
 static void static_style (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *label_size, *label_variancy;
-GtkWidget *combo;
 GtkWidget *entry;
+GtkWidget *label_size, *label_variancy;
+GtkWidget *combo_style, *combo_size, *combo_variancy;
 char token[GAMGI_ENGINE_TOKEN];
 int row;
 
@@ -48,34 +48,40 @@ int row;
  * update style *
  ****************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+combo_style = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo_style));
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_size");
+combo_size = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_size");
 label_size = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_size");
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_variancy");
+combo_variancy = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_variancy");
 label_variancy = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_variancy");
 
 if (row == GAMGI_MESA_WIRED - 1)
   {
-  gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo)->child), "");
-  gtk_widget_set_sensitive (combo, FALSE);
-  gtk_widget_set_sensitive (label_size, FALSE);
+  entry = gtk_bin_get_child (GTK_BIN (combo_size));
   gtk_entry_set_text (GTK_ENTRY (entry), "");
-  gtk_widget_set_sensitive (entry, FALSE);
+  gtk_widget_set_sensitive (combo_size, FALSE);
+  gtk_widget_set_sensitive (label_size, FALSE);
+
+  entry = gtk_bin_get_child (GTK_BIN (combo_variancy));
+  gtk_entry_set_text (GTK_ENTRY (entry), "");
+  gtk_widget_set_sensitive (combo_variancy, FALSE);
   gtk_widget_set_sensitive (label_variancy, FALSE);
   }
 
 if (row == GAMGI_MESA_SOLID - 1)
   {
-  gtk_widget_set_sensitive (combo, TRUE);
+  gtk_widget_set_sensitive (combo_size, TRUE);
   gtk_widget_set_sensitive (label_size, TRUE);
   sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SIZE, gamgi->atom->size);
-  gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo)->child), token);
-  gtk_widget_set_sensitive (entry, TRUE);
+  entry = gtk_bin_get_child (GTK_BIN (combo_size));
+  gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+  gtk_widget_set_sensitive (combo_variancy, TRUE);
   gtk_widget_set_sensitive (label_variancy, TRUE);
   sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_VARIANCY, gamgi->atom->variancy);
+  entry = gtk_bin_get_child (GTK_BIN (combo_variancy));
   gtk_entry_set_text (GTK_ENTRY (entry), token);
   }
 
@@ -94,13 +100,13 @@ if (row == GAMGI_MESA_SOLID - 1)
 static void static_default (int number, char *name, gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
-GtkWidget *entry_atom, *entry_type;
+GtkWidget *entry_atom, *entry_label;
 GtkWidget *entry_mass, *entry_radius, *entry_charge;
 GtkWidget *entry_red, *entry_green, *entry_blue;
 char token[GAMGI_ENGINE_TOKEN];
 
 entry_atom = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_atom");
-entry_type = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_type");
+entry_label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_label");
 
 entry_mass = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_mass");
 entry_radius = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_radius");
@@ -116,16 +122,16 @@ if (number >= 0)
    * A valid element was found: output default values *
    ****************************************************/
 
-  /**********************************************
-   *                  Atom name                 *
-   *                                            *
-   * Atom type (the element name in lower case) *
-   **********************************************/
+  /***********************************************
+   *                   Atom name                 *
+   *                                             *
+   * Atom label (the element name in lower case) *
+   ***********************************************/
 
   gtk_entry_set_text (GTK_ENTRY (entry_atom), name);
 
   gamgi_io_token_lower (name, token);
-  gtk_entry_set_text (GTK_ENTRY (entry_type), token);
+  gtk_entry_set_text (GTK_ENTRY (entry_label), token);
 
   /***********************
    *          Mass       *
@@ -161,7 +167,7 @@ else
    ****************************************/
 
   gtk_entry_set_text (GTK_ENTRY (entry_atom), "");
-  gtk_entry_set_text (GTK_ENTRY (entry_type), "");
+  gtk_entry_set_text (GTK_ENTRY (entry_label), "");
 
   gtk_entry_set_text (GTK_ENTRY (entry_mass), "");
   gtk_entry_set_text (GTK_ENTRY (entry_radius), "");
@@ -174,7 +180,7 @@ else
 
 }
 
-static void static_name (GtkWidget *widget, void *data)
+static void static_element (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
@@ -191,8 +197,7 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_number");
  * should not be used to change name entry again! *
  **************************************************/
 
-gtk_signal_handler_block_by_func (GTK_OBJECT (entry),
-GTK_SIGNAL_FUNC (static_number), window);
+g_signal_handlers_block_by_func (entry, static_number, window);
 
 /************************************
  * get name, get number, set number *
@@ -218,8 +223,7 @@ else
  * accepts changes done directly in that entry    *
  **************************************************/
 
-gtk_signal_handler_unblock_by_func (GTK_OBJECT (entry),
-G_CALLBACK (static_number), window);
+g_signal_handlers_unblock_by_func (entry, static_number, window);
 }
 
 static void static_number (GtkWidget *widget, void *data)
@@ -231,7 +235,7 @@ const char *name;
 char token[GAMGI_ENGINE_TOKEN];
 int number;
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_name");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_element");
 
 /********************************************
  * block changed signal for name entry so   *
@@ -239,8 +243,7 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_name");
  * be used to change number entry again!    *
  ********************************************/
 
-gtk_signal_handler_block_by_func (GTK_OBJECT (entry),
-GTK_SIGNAL_FUNC (static_name), window);
+g_signal_handlers_block_by_func (entry, static_element, window);
 
 /**********************************
  * get number, get name, set name *
@@ -265,8 +268,7 @@ else
  * accepts changes done directly in that entry  *
  ************************************************/
 
-gtk_signal_handler_unblock_by_func (GTK_OBJECT (entry),
-G_CALLBACK (static_name), window);
+g_signal_handlers_unblock_by_func (entry, static_element, window);
 }
 
 /**************** internal function ***************
@@ -424,16 +426,16 @@ token, atom->object.name) == FALSE)
   return;
   }
 
-/************
- * Get type *
- ************/
+/*************
+ * Get label *
+ *************/
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_type");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_label");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_alpha_scan (name, atom->object.type,
-GAMGI_IO_TEXT, GAMGI_CHEM_ATOM_TYPE) == FALSE)
+if (gamgi_io_token_alpha_scan (name, atom->object.label,
+GAMGI_IO_TEXT, GAMGI_CHEM_ATOM_LABEL + 1) == FALSE)
   {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid type", window);
+  gamgi_gtk_dialog_message_create ("Error", "Invalid label", window);
   gamgi_engine_remove_atom (atom);
   return;
   }
@@ -618,7 +620,8 @@ if (row == GAMGI_MESA_SOLID - 1) atom->draw = gamgi_mesa_atom_draw_sphere;
 
 atom->size = gamgi->atom->size;
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_size");
-name = gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo)->child));
+entry = gtk_bin_get_child (GTK_BIN (combo));
+name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (atom->draw == gamgi_mesa_atom_draw_sphere &&
 gamgi_io_token_float_scan (name, &atom->size, GAMGI_MATH_TOLERANCE, FLT_MAX) == FALSE)
   {
@@ -632,7 +635,8 @@ gamgi_io_token_float_scan (name, &atom->size, GAMGI_MATH_TOLERANCE, FLT_MAX) ==
  ************/
  
 atom->variancy = gamgi->atom->variancy;
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_variancy");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_variancy");
+entry = gtk_bin_get_child (GTK_BIN (combo));
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (atom->draw == gamgi_mesa_atom_draw_sphere &&
 gamgi_io_token_float_scan (name, &atom->variancy, 0.0, FLT_MAX) == FALSE)
@@ -648,7 +652,8 @@ gamgi_io_token_float_scan (name, &atom->variancy, 0.0, FLT_MAX) == FALSE)
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_double_scan (name, &atom->object.scale, 0.0, DBL_MAX) == FALSE)
+if (gamgi_io_token_double_scan (name, &atom->object.scale,
+GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid scale", window);
   gamgi_engine_remove_atom (atom);
@@ -748,7 +753,7 @@ static_style (NULL, window);
  ***********************************************/
 
 void gamgi_gtk_atom_create_press (gamgi_window *window_mouse,
-int x, int y, gamgi_window *window_dialog)
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 {
 GtkWidget *dialog = window_dialog->dialog0;
 GtkWidget *entry;
@@ -793,10 +798,9 @@ GtkWidget *notebook;
 GtkWidget *button;
 GtkWidget *label;
 GtkWidget *entry;
-GtkWidget *frame;
 GtkWidget *table;
 GtkWidget *hbox_center, *hbox_left, *hbox_left_left;
-GtkWidget *vbox_dialog, *vbox_page, *vbox_frame, *vbox_top;
+GtkWidget *vbox_dialog, *vbox_page, *vbox_center, *vbox_top, *vbox_top_top;
 GtkWidget *combo;
 GtkListStore *store;
 GtkCellRenderer *renderer;
@@ -823,7 +827,7 @@ gtk_widget_show (vbox_dialog);
  * Atom object *
  ***************/
 
-hbox_center = gtk_hbox_new (TRUE, 5);
+hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_dialog), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
@@ -849,38 +853,32 @@ gtk_widget_show (entry);
 notebook = gtk_notebook_new ();
 gtk_box_pack_start (GTK_BOX (vbox_dialog), notebook, FALSE, FALSE, 0);
 gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_TOP);
-g_signal_connect (GTK_OBJECT (notebook), "switch_page",
+g_signal_connect (notebook, "switch_page",
 G_CALLBACK (static_switch), window);
 g_object_set_data (G_OBJECT (dialog), "notebook", notebook);
 gtk_widget_show (notebook);
 
-/****************
- * Element page *
- ****************/
+/*************
+ * Type page *
+ *************/
 
 vbox_page = gtk_vbox_new (FALSE, 5);
-label = gtk_label_new ("Element");
+label = gtk_label_new (" Type ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 10);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
-/****************
- * Name, Number *
- ****************/
+/*******************
+ * Element, Number *
+ *******************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
@@ -894,7 +892,7 @@ hbox_left_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left_left);
 
-label = gtk_label_new ("Name");
+label = gtk_label_new ("Element");
 gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
@@ -902,9 +900,9 @@ entry = gtk_entry_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
-g_signal_connect (GTK_OBJECT (entry), "changed",
-G_CALLBACK (static_name), window);
-g_object_set_data (G_OBJECT (dialog), "entry_name", entry);
+g_signal_connect (entry, "changed",
+G_CALLBACK (static_element), window);
+g_object_set_data (G_OBJECT (dialog), "entry_element", entry);
 gtk_widget_show (entry);
 
 hbox_left_left = gtk_hbox_new (FALSE, 5);
@@ -919,20 +917,20 @@ entry = gtk_entry_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
-g_signal_connect (GTK_OBJECT (entry), "changed",
+g_signal_connect (entry, "changed",
 G_CALLBACK (static_number), window);
 g_object_set_data (G_OBJECT (dialog), "entry_number", entry);
 gtk_widget_show (entry);
 
-/*******************************
- * Type, Periodic Table Button *
- *******************************/
+/********************************
+ * Label, Periodic Table Button *
+ ********************************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-hbox_left = gtk_hbox_new (FALSE, 25);
+hbox_left = gtk_hbox_new (FALSE, 20);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
@@ -940,53 +938,47 @@ hbox_left_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left_left);
 
-label = gtk_label_new ("Type");
+label = gtk_label_new ("Label");
 gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
 entry = gtk_entry_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_CHEM_ATOM_TYPE);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_CHEM_ATOM_TYPE);
-g_object_set_data (G_OBJECT (dialog), "entry_type", entry);
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_CHEM_ATOM_LABEL);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_CHEM_ATOM_LABEL);
+g_object_set_data (G_OBJECT (dialog), "entry_label", entry);
 gtk_widget_show (entry);
 
 button = gtk_toggle_button_new_with_label ("Table");
 gtk_box_pack_end (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "toggled",
+g_signal_connect (button, "toggled",
 G_CALLBACK (static_table), window);
 g_object_set_data (G_OBJECT (dialog), "button_table", button);
 gtk_widget_show (button);
 
-/*******************
- * Properties page *
- *******************/
+/*****************
+ * Property page *
+ *****************/
 
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Property");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 /************************
  * mass, radius, charge *
  ************************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-vbox_top = gtk_vbox_new (FALSE, 5);
+vbox_top = gtk_vbox_new (FALSE, 10);
 gtk_box_pack_start (GTK_BOX (hbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
@@ -1000,7 +992,7 @@ gtk_widget_show (hbox_left);
 
 button = gtk_toggle_button_new_with_label ("List");
 gtk_box_pack_end (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_atom_property_mass), window);
 g_object_set_data (G_OBJECT (dialog), "button_mass", button);
 gtk_widget_show (button);
@@ -1026,7 +1018,7 @@ gtk_widget_show (hbox_left);
 
 button = gtk_toggle_button_new_with_label ("List");
 gtk_box_pack_end (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_atom_property_radius), window);
 g_object_set_data (G_OBJECT (dialog), "button_radius", button);
 gtk_widget_show (button);
@@ -1052,7 +1044,7 @@ gtk_widget_show (hbox_left);
 
 button = gtk_toggle_button_new_with_label ("List");
 gtk_box_pack_end (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_atom_property_charge), window);
 g_object_set_data (G_OBJECT (dialog), "button_charge", button);
 gtk_widget_show (button);
@@ -1075,25 +1067,19 @@ gtk_widget_show (label);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Analysis");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 /*************************
  * temperature,occupancy *
  *************************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 10);
@@ -1137,25 +1123,19 @@ gtk_widget_show (label);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Position");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 10);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 /**********
  * Origin *
  **********/
 
 vbox_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 hbox_center = gtk_hbox_new (TRUE, 0);
@@ -1214,43 +1194,40 @@ gtk_widget_show (entry);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new (" View ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
-vbox_frame = gtk_vbox_new (TRUE, 5);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_top = gtk_vbox_new (FALSE, 10);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top);
 
-/***********************
- * style,size,variancy *
- ***********************/
+/*******************
+ * Style, Variancy *
+ *******************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-hbox_left = gtk_hbox_new (FALSE, 10);
+hbox_left = gtk_hbox_new (FALSE, 15);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
+vbox_top_top = gtk_vbox_new (FALSE, 10);
+gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top_top);
+
 hbox_left_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_left_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left_left);
 
-label = gtk_label_new ("Style");
-gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
-gtk_widget_show (label);
-
 combo = gtk_combo_box_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left_left), combo, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
-G_CALLBACK (static_style), window);
+gtk_box_pack_end (GTK_BOX (hbox_left_left), combo, FALSE, FALSE, 0);
+g_signal_connect (combo, "changed", G_CALLBACK (static_style), window);
 g_object_set_data (G_OBJECT (dialog), "combo_style", combo);
 gtk_widget_show (combo);
 
@@ -1266,19 +1243,56 @@ renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
-hbox_left_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left_left);
-
-label = gtk_label_new ("Size");
-gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "label_size", label);
+label = gtk_label_new ("Style");
+gtk_box_pack_end (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
+hbox_left_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_left_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left_left);
+
 combo = gtk_combo_box_entry_new ();
 gtk_box_pack_end (GTK_BOX (hbox_left_left), combo, FALSE, FALSE, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (GTK_BIN (combo)->child), GAMGI_GTK_CHAR_5);
-gtk_entry_set_max_length (GTK_ENTRY (GTK_BIN (combo)->child), GAMGI_GTK_CHAR_5);
+entry = gtk_bin_get_child (GTK_BIN (combo));
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+g_object_set_data (G_OBJECT (dialog), "combo_variancy", combo);
+gtk_widget_show (combo);
+
+store = gtk_list_store_new (1, G_TYPE_STRING);
+gtk_list_store_append (store, &iter);
+sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, 0.0);
+gtk_list_store_set (store, &iter, 0, token, -1);
+gtk_list_store_append (store, &iter);
+sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, 1.0);
+gtk_list_store_set (store, &iter, 0, token, -1);
+gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+g_object_unref (store);
+
+gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (combo), 0);
+
+label = gtk_label_new ("Variancy");
+gtk_box_pack_end (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "label_variancy", label);
+gtk_widget_show (label);
+
+/***************
+ * Size, Scale *
+ ***************/
+
+vbox_top_top = gtk_vbox_new (TRUE, 10);
+gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top_top);
+
+hbox_left_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_left_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left_left);
+
+combo = gtk_combo_box_entry_new ();
+gtk_box_pack_end (GTK_BOX (hbox_left_left), combo, FALSE, FALSE, 0);
+entry = gtk_bin_get_child (GTK_BIN (combo));
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 g_object_set_data (G_OBJECT (dialog), "combo_size", combo);
 gtk_widget_show (combo);
 
@@ -1297,28 +1311,32 @@ g_object_unref (store);
 
 gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (combo), 0);
 
-hbox_left_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left_left);
-
-label = gtk_label_new ("Variancy");
-gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "label_variancy", label);
+label = gtk_label_new ("Size");
+gtk_box_pack_end (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "label_size", label);
 gtk_widget_show (label);
 
+hbox_left_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_left_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left_left);
+
 entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
+gtk_box_pack_end (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
-g_object_set_data (G_OBJECT (dialog), "entry_variancy", entry);
+g_object_set_data (G_OBJECT (dialog), "entry_scale", entry);
 gtk_widget_show (entry);
 
+label = gtk_label_new ("Scale");
+gtk_box_pack_end (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
+
 /*********
- * color *
+ * Color *
  *********/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 table = gtk_table_new (1, 7, FALSE);
@@ -1362,29 +1380,6 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 g_object_set_data (G_OBJECT (dialog), "entry_blue", entry);
 gtk_widget_show (entry);
 
-/*********
- * scale *
- *********/
-
-hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
-gtk_widget_show (hbox_center);
-
-hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left);
-
-label = gtk_label_new ("Scale");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
-gtk_widget_show (label);
-
-entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
-g_object_set_data (G_OBJECT (dialog), "entry_scale", entry);
-gtk_widget_show (entry);
-
 /*********************
  * Ok/Cancel buttons *
  *********************/
@@ -1396,17 +1391,15 @@ gtk_widget_show (hbox_center);
 button = gamgi_gtk_dialog_button_create ("Ok", NULL);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_ok), window);
 gtk_widget_show (button);
 
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_widget_grab_focus (button);
-g_signal_connect (G_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_dialog_task0_remove), window);
 gtk_widget_show (button);
 
