@@ -83,13 +83,22 @@ static void static_press_geometry (gamgi_object *object, void *data);
  * common functions *
  ********************
 
-static void static_global (GtkWidget *widget, void *data);
+static void static_list (GtkWidget *widget, void *data);
 
 static void static_mode (GtkWidget *widget, void *data);
 
 static void static_switch (GtkNotebook *notebook,
 GtkNotebookPage *page, int tag, void *data);
 
+static gamgi_bool static_grab (gamgi_window *window);
+
+static gamgi_bool static_apply (gamgi_atom *atom, gamgi_bool local,
+gamgi_window *window);
+
+static void static_ok_global (gamgi_window *window);
+
+static void static_ok_local (gamgi_window *window);
+
 static void static_ok (GtkWidget *widget, void *data);
 
 static void static_init (gamgi_window *window);
