@@ -35,7 +35,7 @@ static void static_press (gamgi_object *object, void *data);
  **********************/
 
 void gamgi_gtk_bond_link_press (gamgi_window *window_mouse,
-int x, int y, gamgi_window *window_dialog);
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog);
 
 void gamgi_gtk_bond_link (GtkWidget *widget, void *data);
 
