@@ -13,8 +13,10 @@
 #include "gamgi_gtk.h"
 #include "gamgi_mesa.h"
 #include "gamgi_math.h"
+#include "gamgi_io.h"
 #include "gamgi_global.h"
 
+#include "gamgi_engine_list.h"
 #include "gamgi_engine_find.h"
 #include "gamgi_gtk_dialog.h"
 #include "gamgi_gtk_history.h"
@@ -23,6 +25,22 @@
 #include "gamgi_mesa_select.h"
 #include "gamgi_mesa_bond.h"
 #include "gamgi_io_token.h"
+#include "gamgi_global_selection.h"
+
+static struct {
+gamgi_bool new[10];
+
+char name[GAMGI_ENGINE_TOKEN];
+
+float order;
+float covalency;
+
+void (*draw) (gamgi_bond *);
+float size;
+double scale;
+
+gamgi_bool color;
+float red, green, blue; } cache;
 
 static void static_color (GtkWidget *widget, void *data)
 {
@@ -166,257 +184,446 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
 }
 
-/************ internal function ************
- *                                         *
- *               STATIC_GLOBAL             *
- *                                         *
- * Makes the bond entry sensitive when the *
- * local button is pressed and insensitive *
- * when the global button is pressed.      *
- *                                         *
- *******************************************/
-
-static void static_global (GtkWidget *widget, void *data)
+static void static_list (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *hbox, *entry, *button;
-
-hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_bond");
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_bond");
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+GtkWidget *label, *button;
 
+label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_bond");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   {
-  /****************************
-   * Choose the bond directly *
-   ****************************/
+  /*********************************
+   * modify a single bond directly *
+   *********************************/
 
-  gtk_widget_set_sensitive (hbox, TRUE);
+  gtk_label_set_text (GTK_LABEL (label), "Bond");
   }
 else
   {
-  /****************************************
-   * Choose the bonds previously selected *
-   ****************************************/
+  /*********************************************
+   * modify multiple bonds previously selected *
+   *********************************************/
 
-  gtk_widget_set_sensitive (hbox, FALSE);
+  gtk_label_set_text (GTK_LABEL (label), "Name");
   static_reset (window);
   }
 }
 
-/****************** internal function ******************
- *                                                     *
- *                      STATIC_OK                      *
- *                                                     *
- * When the user clicks the Ok button, the parameters  *
- * in the dialog window are atributted to the atom or  *
- * atoms currently selected, overwriting the old ones. *
- *                                                     *
- *******************************************************/
+static gamgi_bool static_grab (gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+GtkWidget *combo;
+const char *name;
+int row, i = 0;
+
+/********************
+ * order, covalency *
+ ********************/
+
+cache.new[++i] = FALSE;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_order");
+entry = gtk_bin_get_child (GTK_BIN (combo));
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[i] = TRUE;
+  if (gamgi_io_token_float_scan (name, &cache.order, 0, FLT_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid order data", window);
+    return FALSE;
+    }
+  }
+
+cache.new[++i] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_covalency");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[i] = TRUE;
+  if (gamgi_io_token_float_scan (name, &cache.covalency, 0.0, FLT_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid covalency data", window);
+    return FALSE;
+    }
+  }
+
+/**********************
+ * style, size, scale *
+ **********************/
+
+cache.new[++i] = FALSE;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row < 2)
+  {
+  cache.new[i] = TRUE;
+  if (row == GAMGI_MESA_WIRED - 1) cache.draw = gamgi_mesa_bond_draw_line;
+  if (row == GAMGI_MESA_SOLID - 1) cache.draw = gamgi_mesa_bond_draw_cylinder;
+  }
+
+cache.new[++i] = FALSE;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_size");
+entry = gtk_bin_get_child (GTK_BIN (combo));
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[i] = TRUE;
+  if (gamgi_io_token_float_scan (name, &cache.size, 0.0, FLT_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid size data", window);
+    return FALSE;
+    }
+  }
+
+cache.new[++i] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[i] = TRUE;
+  if (gamgi_io_token_double_scan (name, &cache.scale,
+  GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid scale data", window);
+    return FALSE;
+    }
+  }
+
+/***************************
+ * color, red, green, blue *
+ ***************************/
+   
+cache.new[++i] = FALSE;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_color");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row < 2)
+  {
+  cache.new[i] = TRUE;
+  if (row == GAMGI_GTK_YES - 1) cache.color = TRUE;
+  if (row == GAMGI_GTK_NO - 1) cache.color = FALSE;
+  }
+
+cache.new[++i] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_red");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[i] = TRUE;
+  if (gamgi_io_token_float_scan (name,
+  &cache.red, 0.0, 1.0) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid color data", window);
+    return FALSE;
+    }
+  }
+
+cache.new[++i] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_green");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[i] = TRUE;
+  if (gamgi_io_token_float_scan (name,
+  &cache.green, 0.0, 1.0) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid color data", window);
+    return FALSE;
+    }
+  }
+
+cache.new[++i] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_blue");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[i] = TRUE;
+  if (gamgi_io_token_float_scan (name,
+  &cache.blue, 0.0, 1.0) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid color data", window);
+    return FALSE;
+    }
+  }
+
+return TRUE;
+}
+
+static gamgi_bool static_apply (gamgi_bond *bond, gamgi_bool local,
+gamgi_window *window)
+{
+void (*draw) (gamgi_bond *);
+char name[GAMGI_ENGINE_TOKEN];
+double order, covalency, scale;
+float size, red, green, blue;
+int color, i = 0;
+
+/*************************
+ * import data from bond *
+ *************************/
+
+strcpy (name, bond->object.name);
+
+covalency = bond->covalency;
+order = bond->order;
+
+draw = bond->draw;
+size = bond->size;
+scale = bond->object.scale;
+color = bond->color;
+red = bond->red;
+green = bond->green;
+blue = bond->blue;
+
+/***************************************
+ * set default size when style changes *
+ ***************************************/
+
+if (cache.new[3] == TRUE && cache.draw != bond->draw)
+  if (cache.new[4] == FALSE) size = gamgi->bond->size;
+
+/*************************************************
+ * set default red,green,blue when color changes *
+ *************************************************/
+
+if (cache.new[6] == TRUE && cache.color != bond->color)
+  {
+  if (cache.new[7] == FALSE) red = gamgi->bond->red;
+  if (cache.new[8] == FALSE) green = gamgi->bond->green;
+  if (cache.new[9] == FALSE) blue = gamgi->bond->blue;
+  }
+
+/******************
+ * apply new data *
+ ******************/
+
+if (cache.new[i++] == TRUE)
+  strcpy (name, cache.name);
+
+if (cache.new[i++] == TRUE)
+  order = cache.order;
+if (cache.new[i++] == TRUE)
+  covalency = cache.covalency;
+
+if (cache.new[i++] == TRUE)
+  draw = cache.draw;
+if (cache.new[i++] == TRUE)
+  {
+  size = cache.size;
+  if (draw == gamgi_mesa_bond_draw_line)
+    {
+    if (local == TRUE)
+      gamgi_gtk_dialog_message_create ("Error", "Invalid size", window);
+    return FALSE;
+    }
+  }
+if (cache.new[i++] == TRUE)
+  scale = cache.scale;
+if (cache.new[i++] == TRUE)
+  color = cache.color;
+if (cache.new[i++] == TRUE)
+  {
+  red = cache.red;
+  if (color == FALSE)
+    {
+    if (local == TRUE)
+      gamgi_gtk_dialog_message_create ("Error", "Invalid color data", window);
+    return FALSE;
+    }
+  }
+if (cache.new[i++] == TRUE)
+  {
+  green = cache.green;
+  if (color == FALSE)
+    {
+    if (local == TRUE)
+      gamgi_gtk_dialog_message_create ("Error", "Invalid color data", window);
+    return FALSE;
+    }
+  }
+if (cache.new[i++] == TRUE)
+  {
+  blue = cache.blue;
+  if (color == FALSE)
+    {
+    if (local == TRUE)
+      gamgi_gtk_dialog_message_create ("Error", "Invalid color data", window);
+    return FALSE;
+    }
+  }
+
+/***************************************
+ * Save current layer as undo buffer   *
+ * layer so it can be recovered later. *
+ ***************************************/
+
+if (local == TRUE)
+  gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
+
+/*************************
+ * export data from bond *
+ *************************/
+
+strcpy (bond->object.name, name);
+
+bond->covalency = covalency;
+bond->order = order;
+
+bond->draw = draw;
+bond->size = size;
+bond->object.scale = scale;
+bond->color = color;
+bond->red = red;
+bond->green = green;
+bond->blue = blue;
+
+return TRUE;
+}
+
+static void static_ok_global (gamgi_window *window)
+{
+gamgi_object *object;
+gamgi_dlist *dlist;
+gamgi_slist *slist, *start;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+const char *name;
+char line[GAMGI_ENGINE_LINE];
+char string[GAMGI_ENGINE_STRING];
+
+if (gamgi->bonds == NULL)
+  { gamgi_gtk_dialog_message_create ("Error",
+  "Empty list of bond objects", window); return; }
+
+/****************************
+ * Pick name (possibly new) *
+ ****************************/
+
+cache.new[0] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_bond");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[0] = TRUE;
+  if (gamgi_io_token_alpha_scan (name,
+  cache.name, GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid bond identity", window);
+    return;
+    }
+  }
+
+if (static_grab (window) == FALSE) return;
+
+/************************************************
+ * for all windows: save layers as undo layers, *
+ * set current layer as new current object      *
+ ************************************************/
+
+gamgi_global_selection_undo ();
+gamgi_global_selection_focus ();
+
+/*******************************************
+ * modify bond data as specified in dialog *
+ *******************************************/
+
+start = NULL;
+for (dlist = gamgi->bonds; dlist != NULL; dlist = dlist->next)
+  if (static_apply (GAMGI_CAST_BOND dlist->data, FALSE, window) == FALSE)
+    {
+    start = gamgi_engine_slist_add_start (start);
+    start->data = dlist->data;
+    }
+
+if (start != NULL)
+  {
+  sprintf (line, "The following objects could not be modified:\n");
+
+  start = gamgi_engine_slist_invert (start);
+  for (slist = start; slist != NULL; slist = slist->next)
+    {
+    if (slist != start) strcat (line, ", ");
+
+    if (strlen (line) > GAMGI_ENGINE_LINE - GAMGI_ENGINE_STRING)
+      { strcat (line, "..."); break; }
+
+    object = GAMGI_CAST_OBJECT slist->data;
+    sprintf (string, "%s %d", object->name, object->number);
+    strcat (line, string);
+    }
+  gamgi_gtk_dialog_message_create ("Error", line, window);
+  gamgi_engine_slist_remove_all (start);
+  }
+
+/*****************************************
+ * For all windows: redraw gl_area image *
+ *****************************************/
+
+gamgi_global_selection_draw ();
+
+/****************
+ * reset dialog *
+ ****************/
+
+static_reset (window);
+}
+
+static void static_ok_local (gamgi_window *window)
+{
+gamgi_bond *bond;
+GtkWidget *dialog = window->dialog0;
+
+/*******************************************
+ * Pick object and get name (possibly new) *
+ *******************************************/
+
+cache.new[0] = TRUE;
+bond = GAMGI_CAST_BOND gamgi_gtk_object_number (dialog,
+"entry_bond", GAMGI_ENGINE_BOND, window, cache.name);
+if (bond == NULL)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid bond identity", window);
+  return;
+  }
+
+if (static_grab (window) == FALSE) return;
+
+/*******************************************
+ * modify bond data as specified in dialog *
+ *******************************************/
+
+if (static_apply (bond, TRUE, window) == FALSE) return;
+
+/************************
+ * Redraw gl_area image *
+ ************************/
+
+gtk_widget_queue_draw (window->area);
+
+/****************
+ * reset dialog *
+ ****************/
+
+static_reset (window);
+}
 
 static void static_ok (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
-gamgi_bond *bond;
-void (*draw) (gamgi_bond *);
 GtkWidget *dialog = window->dialog0;
-GtkWidget *entry;
-GtkWidget *button, *combo;
-char token[GAMGI_ENGINE_TOKEN];
-const char *name;
-double scale;
-float covalency, order;
-float size;
-float red, green, blue;
-gamgi_bool color;
-int row;
+GtkWidget* button;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
-  {
-  /****************
-   * Local method *
-   ****************/
+/*********************************************
+ * modify data: execute global or local task *
+ *********************************************/
 
-  /**************************************
-   * Get name (possibly new) and number *
-   **************************************/
-
-  bond = GAMGI_CAST_BOND gamgi_gtk_object_number (dialog,
-  "entry_bond", GAMGI_ENGINE_BOND, window, token);
-  if (bond == NULL)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Bond Object", window);
-    return;
-    }
-
-  /**************************
-   * get initial parameters *
-   **************************/
-
-  covalency = bond->covalency;
-  order = bond->order;
-
-  draw = bond->draw;
-  size = bond->size;
-
-  color = bond->color;
-  red = bond->red;
-  green = bond->green;
-  blue = bond->blue;
-
-  scale = bond->object.scale;
-
-  /*****************
-   * Get covalency *
-   *****************/
-
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_covalency");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE && 
-  gamgi_io_token_float_scan (name, &covalency, 0.0, FLT_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Covalency Data", window);
-    return;
-    }
-
-   /************
-   * Get order *
-   *************/
-
-  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_order");
-  entry = gtk_bin_get_child (GTK_BIN (combo));
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE && 
-  gamgi_io_token_float_scan (name, &order, 0, FLT_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Order Data", window);
-    return;
-    }
-
-  /*************
-   * Get style *
-   *************/
-
-  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
-  row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-  if (row == GAMGI_MESA_WIRED - 1) draw = gamgi_mesa_bond_draw_line;
-  if (row == GAMGI_MESA_SOLID - 1) draw = gamgi_mesa_bond_draw_cylinder;
-
-  /*************
-   * Get scale *
-   *************/
-
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_double_scan (name,
-  &scale, GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Scale Data", window);
-    return;
-    }
-
-  /************
-   * Get size *
-   ************/
-
-  if (draw != bond->draw) size = gamgi->bond->size;
-  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_size");
-  entry = gtk_bin_get_child (GTK_BIN (combo));
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE && (draw == gamgi_mesa_bond_draw_line
-  || gamgi_io_token_float_scan (name, &size, 0.0, FLT_MAX) == FALSE))
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Size Data", window);
-    return;
-    }
-
-  /*************
-   * Get color *
-   *************/
-   
-  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_color");
-  row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-  if (row == GAMGI_GTK_YES - 1) color = TRUE;
-  if (row == GAMGI_GTK_NO - 1) color = FALSE;
-
-  /**********************
-   * Get red,green,blue *
-   **********************/
-
-  if (color != bond->color) red = gamgi->bond->red;
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_red");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE && (color == FALSE
-  || gamgi_io_token_float_scan (name, &red, 0.0, 1.0) == FALSE))
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Color Data", window);
-    return;
-    }
-
-  if (color != bond->color) green = gamgi->bond->green;
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_green");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE && (color == FALSE
-  || gamgi_io_token_float_scan (name, &green, 0.0, 1.0) == FALSE))
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Color Data", window);
-    return;
-    }
-
-  if (color != bond->color) blue = gamgi->bond->blue;
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_blue");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE && (color == FALSE
-  || gamgi_io_token_float_scan (name, &blue, 0.0, 1.0) == FALSE))
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Color Data", window);
-    return;
-    }
-
-  /********************************************************
-   * Data is ok: save current data and update to new data *
-   ********************************************************/
- 
-  /***************************************
-   * Save current layer as undo buffer   *
-   * layer so it can be recovered later. * 
-   ***************************************/
-
-  gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
-
-  /*****************************
-   * transfer new data to bond *
-   *****************************/
-
-  bond->covalency = covalency;
-  bond->order = order;
-
-  bond->draw = draw;
-  bond->size = size;
-
-  bond->color = color;
-  bond->red = red;
-  bond->green = green;
-  bond->blue = blue;
-
-  bond->object.scale = scale;
-
-  /*********************************************
-   * Update the bond name, which might be new. *
-   *********************************************/
-
-  strcpy (bond->object.name, token);
-  }
-
-/***********************************************************
- * Update statusbar, redraw gl_area image and reset dialog *
- ***********************************************************/
-
-gamgi_gtk_statusbar_focus_modify (window);
-gtk_widget_queue_draw (window->area);
-static_reset (window);
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  static_ok_global (window);
+else
+  static_ok_local (window);
 }
 
 static void static_init (gamgi_window *window)
@@ -559,7 +766,7 @@ GtkWidget *button;
  * local mouse selection only *
  ******************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE ||
 window_dialog != window_mouse) return;
 
@@ -625,11 +832,11 @@ gtk_widget_show (hbox_left);
 
 hbox_left_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "hbox_bond", hbox_left_left);
 gtk_widget_show (hbox_left_left);
 
 label = gtk_label_new ("Bond");
 gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "label_bond", label);
 gtk_widget_show (label);
 
 entry = gtk_entry_new ();
@@ -639,15 +846,15 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 g_object_set_data (G_OBJECT (dialog), "entry_bond", entry);
 gtk_widget_show (entry);
 
-/**********
- * Global *
- **********/
+/********
+ * List *
+ ********/
 
-button = gtk_toggle_button_new_with_label ("Global");
+button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "toggled",
-G_CALLBACK (static_global), window);
-g_object_set_data (G_OBJECT (dialog), "button_global", button);
+G_CALLBACK (static_list), window);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /************
@@ -754,7 +961,7 @@ hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-hbox_left = gtk_hbox_new (FALSE, 20);
+hbox_left = gtk_hbox_new (FALSE, 35);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
