@@ -19,7 +19,16 @@ static void static_style (GtkWidget *widget, void *data);
 
 static void static_reset (gamgi_window *window);
 
-static void static_global (GtkWidget *widget, void *data);
+static void static_list (GtkWidget *widget, void *data);
+
+static gamgi_bool static_grab (gamgi_window *window);
+
+static gamgi_bool static_apply (gamgi_bond *bond, gamgi_bool local,
+gamgi_window *window);
+
+static void static_ok_global (gamgi_window *window);
+
+static void static_ok_local (gamgi_window *window);
 
 static void static_ok (GtkWidget *widget, void *data);
 
