@@ -406,21 +406,21 @@ char token[GAMGI_ENGINE_TOKEN];
  *********************/
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE)
+if (gtk_widget_is_sensitive (entry) == TRUE)
   {
   sprintf (token, "%.*f", gamgi->gamgi->length, GAMGI_PHYS_CELL_X);
   gtk_entry_set_text (GTK_ENTRY (entry), token);
   }
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE)
+if (gtk_widget_is_sensitive (entry) == TRUE)
   {
   sprintf (token, "%.*f", gamgi->gamgi->length, GAMGI_PHYS_CELL_Y);
   gtk_entry_set_text (GTK_ENTRY (entry), token);
   }
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE)
+if (gtk_widget_is_sensitive (entry) == TRUE)
   {
   sprintf (token, "%.*f", gamgi->gamgi->length, GAMGI_PHYS_CELL_Z);
   gtk_entry_set_text (GTK_ENTRY (entry), token);
@@ -431,21 +431,21 @@ if (GTK_WIDGET_SENSITIVE (entry) == TRUE)
  **************************/
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e1");
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE)
+if (gtk_widget_is_sensitive (entry) == TRUE)
   {
   sprintf (token, "%.*f", gamgi->gamgi->angle, GAMGI_PHYS_CELL_E1);
   gtk_entry_set_text (GTK_ENTRY (entry), token);
   }
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e2");
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE)
+if (gtk_widget_is_sensitive (entry) == TRUE)
   {
   sprintf (token, "%.*f", gamgi->gamgi->angle, GAMGI_PHYS_CELL_E2);
   gtk_entry_set_text (GTK_ENTRY (entry), token);
   }
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e3");
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE)
+if (gtk_widget_is_sensitive (entry) == TRUE)
   {
   sprintf (token, "%.*f", gamgi->gamgi->angle, GAMGI_PHYS_CELL_E3);
   gtk_entry_set_text (GTK_ENTRY (entry), token);
@@ -459,7 +459,7 @@ gamgi_cell *cell;
 GtkWidget *dialog = window->dialog0;
 GtkWidget *button;
 GtkWidget *combo;
-GtkEntry *entry;
+GtkWidget *entry;
 const char *name;
 double origin[3], euler[3];
 int o1, o2, o3;
@@ -497,7 +497,7 @@ if (gamgi_gtk_cell_symmetry_create (&cell->lattice,
  * get lattice parameters *
  **************************/
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_a");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_a");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_double_scan (name, 
 &cell->a, GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
@@ -507,7 +507,7 @@ if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_double_scan (name,
   return;
   }
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_b");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_b");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_double_scan (name, 
 &cell->b, GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
@@ -517,7 +517,7 @@ if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_double_scan (name,
   return;
   }
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_c");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_c");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_double_scan (name, 
 &cell->c, GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
@@ -527,7 +527,7 @@ if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_double_scan (name,
   return;
   }
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_ab");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_ab");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_double_scan (name, 
 &cell->ab, GAMGI_MATH_TOLERANCE_ANGLE, 180.0) == FALSE)
@@ -537,7 +537,7 @@ if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_double_scan (name,
   return;
   }
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_ac");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_ac");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_double_scan (name, 
 &cell->ac, GAMGI_MATH_TOLERANCE_ANGLE, 180.0) == FALSE)
@@ -547,7 +547,7 @@ if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_double_scan (name,
   return;
   }
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_bc");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_bc");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_double_scan (name, 
 &cell->bc, GAMGI_MATH_TOLERANCE_ANGLE, 180.0) == FALSE)
@@ -573,9 +573,9 @@ if (gamgi_gtk_cell_symmetry_parameters (cell, cell->lattice, &cell->a,
  * Get position *
  ****************/
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_x");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE &&
+if (gtk_widget_is_sensitive (entry) == TRUE &&
 gamgi_io_token_double_scan (name, &origin[0], -DBL_MAX, DBL_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Origin Data", window);
@@ -583,9 +583,9 @@ gamgi_io_token_double_scan (name, &origin[0], -DBL_MAX, DBL_MAX) == FALSE)
   return;
   }
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_y");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE &&
+if (gtk_widget_is_sensitive (entry) == TRUE &&
 gamgi_io_token_double_scan (name, &origin[1], -DBL_MAX, DBL_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Origin Data", window);
@@ -593,9 +593,9 @@ gamgi_io_token_double_scan (name, &origin[1], -DBL_MAX, DBL_MAX) == FALSE)
   return;
   }
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_z");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE &&
+if (gtk_widget_is_sensitive (entry) == TRUE &&
 gamgi_io_token_double_scan (name, &origin[2], -DBL_MAX, DBL_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Origin Data", window);
@@ -607,9 +607,9 @@ gamgi_io_token_double_scan (name, &origin[2], -DBL_MAX, DBL_MAX) == FALSE)
  * Get rotation *
  ****************/
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_e1");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e1");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE &&
+if (gtk_widget_is_sensitive (entry) == TRUE &&
 gamgi_io_token_double_scan (name, &euler[0], 0.0, 180.0) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Angle Data", window);
@@ -617,9 +617,9 @@ gamgi_io_token_double_scan (name, &euler[0], 0.0, 180.0) == FALSE)
   return;
   }
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_e2");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e2");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE &&
+if (gtk_widget_is_sensitive (entry) == TRUE &&
 gamgi_io_token_double_scan (name, &euler[1], 0.0, 360.0) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Angle Data", window);
@@ -627,9 +627,9 @@ gamgi_io_token_double_scan (name, &euler[1], 0.0, 360.0) == FALSE)
   return;
   }
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_e3");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e3");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE &&
+if (gtk_widget_is_sensitive (entry) == TRUE &&
 gamgi_io_token_double_scan (name, &euler[2], 0.0, 360.0) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Angle Data", window);
@@ -653,9 +653,9 @@ cell->type = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
  **************/
 
 cell->n1 = 1;
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_n1");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_n1");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE && gamgi_io_token_int_scan (name, 
+if (gtk_widget_is_sensitive (entry) == TRUE && gamgi_io_token_int_scan (name, 
 &cell->n1, 1, INT_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Cell Data n1", window);
@@ -664,9 +664,9 @@ if (GTK_WIDGET_SENSITIVE (entry) == TRUE && gamgi_io_token_int_scan (name,
   }
 
 cell->n2 = 1;
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_n2");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_n2");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE && gamgi_io_token_int_scan (name, 
+if (gtk_widget_is_sensitive (entry) == TRUE && gamgi_io_token_int_scan (name, 
 &cell->n2, 1, INT_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Cell Data n2", window);
@@ -675,9 +675,9 @@ if (GTK_WIDGET_SENSITIVE (entry) == TRUE && gamgi_io_token_int_scan (name,
   }
 
 cell->n3 = 1;
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_n3");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_n3");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE && gamgi_io_token_int_scan (name, 
+if (gtk_widget_is_sensitive (entry) == TRUE && gamgi_io_token_int_scan (name, 
 &cell->n3, 1, INT_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Cell Data n3", window);
@@ -689,9 +689,9 @@ if (GTK_WIDGET_SENSITIVE (entry) == TRUE && gamgi_io_token_int_scan (name,
  * V1, V2, V3, V12, V13, V23 *
  *****************************/
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_v1");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v1");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE && gamgi_io_token_double_scan (name, 
+if (gtk_widget_is_sensitive (entry) == TRUE && gamgi_io_token_double_scan (name, 
 &cell->v1, GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid volume parameters", window);
@@ -699,9 +699,9 @@ if (GTK_WIDGET_SENSITIVE (entry) == TRUE && gamgi_io_token_double_scan (name,
   return;
   }
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_v2");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v2");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE && gamgi_io_token_double_scan (name, 
+if (gtk_widget_is_sensitive (entry) == TRUE && gamgi_io_token_double_scan (name, 
 &cell->v2, GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid volume parameters", window);
@@ -709,9 +709,9 @@ if (GTK_WIDGET_SENSITIVE (entry) == TRUE && gamgi_io_token_double_scan (name,
   return;
   }
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_v3");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v3");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE && gamgi_io_token_double_scan (name, 
+if (gtk_widget_is_sensitive (entry) == TRUE && gamgi_io_token_double_scan (name, 
 &cell->v3, GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid volume parameters", window);
@@ -719,9 +719,9 @@ if (GTK_WIDGET_SENSITIVE (entry) == TRUE && gamgi_io_token_double_scan (name,
   return;
   }
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_v12");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v12");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE && gamgi_io_token_double_scan (name, 
+if (gtk_widget_is_sensitive (entry) == TRUE && gamgi_io_token_double_scan (name, 
 &cell->v12, GAMGI_MATH_TOLERANCE_ANGLE, 180.0) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid volume parameters", window);
@@ -729,9 +729,9 @@ if (GTK_WIDGET_SENSITIVE (entry) == TRUE && gamgi_io_token_double_scan (name,
   return;
   }
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_v13");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v13");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE && gamgi_io_token_double_scan (name, 
+if (gtk_widget_is_sensitive (entry) == TRUE && gamgi_io_token_double_scan (name, 
 &cell->v13, GAMGI_MATH_TOLERANCE_ANGLE, 180.0) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid volume parameters", window);
@@ -739,9 +739,9 @@ if (GTK_WIDGET_SENSITIVE (entry) == TRUE && gamgi_io_token_double_scan (name,
   return;
   }
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_v23");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_v23");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE && gamgi_io_token_double_scan (name, 
+if (gtk_widget_is_sensitive (entry) == TRUE && gamgi_io_token_double_scan (name, 
 &cell->v23, GAMGI_MATH_TOLERANCE_ANGLE, 180.0) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid volume parameters", window);
@@ -796,7 +796,7 @@ if (cell->type == GAMGI_PHYS_PARALLELEPIPED)
  ***************/
 
 o1 = 0; 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_o1");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_o1");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_int_scan (name, &o1, -INT_MAX, INT_MAX) == FALSE)
   {
@@ -806,7 +806,7 @@ if (gamgi_io_token_int_scan (name, &o1, -INT_MAX, INT_MAX) == FALSE)
   }
 
 o2 = 0;
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_o2");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_o2");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_int_scan (name, &o2, -INT_MAX, INT_MAX) == FALSE)
   {
@@ -816,7 +816,7 @@ if (gamgi_io_token_int_scan (name, &o2, -INT_MAX, INT_MAX) == FALSE)
   }
 
 o3 = 0;
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_o3");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_o3");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_int_scan (name, &o3, -INT_MAX, INT_MAX) == FALSE)
   {
@@ -865,7 +865,7 @@ cell->axes_vectors = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
  * red *
  *******/
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_red");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_red");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_float_scan (name, &cell->red, 0.0, 1.0) == FALSE)
   {
@@ -878,7 +878,7 @@ if (gamgi_io_token_float_scan (name, &cell->red, 0.0, 1.0) == FALSE)
  * green *
  *********/
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_green");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_green");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_float_scan (name, &cell->green, 0.0, 1.0) == FALSE)
   {
@@ -891,7 +891,7 @@ if (gamgi_io_token_float_scan (name, &cell->green, 0.0, 1.0) == FALSE)
  * blue *
  ********/
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_blue");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_blue");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_float_scan (name, &cell->blue, 0.0, 1.0) == FALSE)
   {
@@ -904,7 +904,7 @@ if (gamgi_io_token_float_scan (name, &cell->blue, 0.0, 1.0) == FALSE)
  * Get scale *
  *************/
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_double_scan (name, &cell->object.scale,
 GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
@@ -1124,7 +1124,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
   { gamgi_gtk_cell_align_press (window_dialog, x, y); return; }
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
-if (GTK_WIDGET_SENSITIVE (entry) == FALSE) return;
+if (gtk_widget_is_sensitive (entry) == FALSE) return;
 
 gamgi_mesa_area_unproject (window_mouse, x, y, &x_3d, &y_3d, &z_3d);
 
