@@ -733,7 +733,7 @@ driver = (const int *) g_object_get_data (G_OBJECT (dialog), "driver");
 position[0] = 0;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE && 
+if (gtk_widget_is_sensitive (entry) == TRUE && 
 gamgi_io_token_double_scan (name, &position[0], -DBL_MAX, DBL_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Vector Coordinates", window);
@@ -743,7 +743,7 @@ gamgi_io_token_double_scan (name, &position[0], -DBL_MAX, DBL_MAX) == FALSE)
 position[1] = 0;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE && 
+if (gtk_widget_is_sensitive (entry) == TRUE && 
 gamgi_io_token_double_scan (name, &position[1], -DBL_MAX, DBL_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Vector Coordinates", window);
@@ -753,7 +753,7 @@ gamgi_io_token_double_scan (name, &position[1], -DBL_MAX, DBL_MAX) == FALSE)
 position[2] = 0;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE &&
+if (gtk_widget_is_sensitive (entry) == TRUE &&
 gamgi_io_token_double_scan (name, &position[2], -DBL_MAX, DBL_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Vector Coordinates", window);
@@ -898,7 +898,7 @@ if (object->class != GAMGI_ENGINE_ATOM)
 n_atoms = 0;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_number");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE && gamgi_io_token_int_scan (name, 
+if (gtk_widget_is_sensitive (entry) == TRUE && gamgi_io_token_int_scan (name, 
 &n_atoms, GAMGI_PHYS_RCP_ATOMS, INT_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Atom Number", window);
