@@ -41,13 +41,13 @@ static void static_clean (gamgi_cell *cell, gamgi_window *window);
 
 static void static_global (GtkWidget *widget, void *data);
 
-static void static_object (gamgi_cell *cell, 
+static void static_ok_object (gamgi_cell *cell, 
 gamgi_object *object, gamgi_window *window);
 
-static void static_crystallographic (gamgi_cell *cell, 
+static void static_ok_crystal (gamgi_cell *cell, 
 gamgi_object *object, gamgi_window *window);
 
-static void static_random (gamgi_cell *cell, 
+static void static_ok_random (gamgi_cell *cell, 
 gamgi_object *object, gamgi_window *window);
 
 static void static_ok (GtkWidget *widget, void *data);
