@@ -1683,21 +1683,21 @@ static_type (NULL, window);
 gamgi_math_position_cell_translation_get (cell, origin);
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE)
+if (gtk_widget_is_sensitive (entry) == TRUE)
   {
   sprintf (string, "%.*f", gamgi->gamgi->length, origin[0]);
   gtk_entry_set_text (GTK_ENTRY (entry), string);
   }
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE)
+if (gtk_widget_is_sensitive (entry) == TRUE)
   {
   sprintf (string, "%.*f", gamgi->gamgi->length, origin[1]);
   gtk_entry_set_text (GTK_ENTRY (entry), string);
   }
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE)
+if (gtk_widget_is_sensitive (entry) == TRUE)
   {
   sprintf (string, "%.*f", gamgi->gamgi->length, origin[2]);
   gtk_entry_set_text (GTK_ENTRY (entry), string);
@@ -1710,21 +1710,21 @@ if (GTK_WIDGET_SENSITIVE (entry) == TRUE)
 gamgi_math_position_cell_rotation_get (cell, euler);
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e1");
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE)
+if (gtk_widget_is_sensitive (entry) == TRUE)
   {
   sprintf (string, "%.*f", gamgi->gamgi->angle, euler[0]);
   gtk_entry_set_text (GTK_ENTRY (entry), string);
   }
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e2");
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE)
+if (gtk_widget_is_sensitive (entry) == TRUE)
   {
   sprintf (string, "%.*f", gamgi->gamgi->angle, euler[1]);
   gtk_entry_set_text (GTK_ENTRY (entry), string);
   }
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e3");
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE)
+if (gtk_widget_is_sensitive (entry) == TRUE)
   {
   sprintf (string, "%.*f", gamgi->gamgi->angle, euler[2]);
   gtk_entry_set_text (GTK_ENTRY (entry), string);
@@ -2783,7 +2783,6 @@ gtk_widget_show (hbox_center);
 button = gamgi_gtk_dialog_button_create ("Ok", NULL);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 g_signal_connect (button, "clicked",
 G_CALLBACK (static_ok), window);
 gtk_widget_show (button);
@@ -2791,7 +2790,6 @@ gtk_widget_show (button);
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_widget_grab_focus (button);
 g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_dialog_task0_remove), window);
