@@ -582,7 +582,7 @@ if (row == GAMGI_GTK_NONE - 1) direction->autonomy = GAMGI_GTK_NONE;
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_thickness");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE &&
+if (gtk_widget_is_sensitive (entry) == TRUE &&
 gamgi_io_token_double_scan (name, &direction->thickness, 
 GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
   {
@@ -605,7 +605,7 @@ if (cell == NULL) return TRUE;
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_o1");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE &&
+if (gtk_widget_is_sensitive (entry) == TRUE &&
 gamgi_io_token_int_scan (name, &direction->node[0], -INT_MAX, INT_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid direction node", window);
@@ -615,7 +615,7 @@ gamgi_io_token_int_scan (name, &direction->node[0], -INT_MAX, INT_MAX) == FALSE)
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_o2");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE &&
+if (gtk_widget_is_sensitive (entry) == TRUE &&
 gamgi_io_token_int_scan (name, &direction->node[1], -INT_MAX, INT_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid direction node", window);
@@ -625,7 +625,7 @@ gamgi_io_token_int_scan (name, &direction->node[1], -INT_MAX, INT_MAX) == FALSE)
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_o3");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE &&
+if (gtk_widget_is_sensitive (entry) == TRUE &&
 gamgi_io_token_int_scan (name, &direction->node[2], -INT_MAX, INT_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid direction node", window);
