@@ -188,6 +188,21 @@ gtk_widget_set_style (widget, style);
 g_object_unref (style);
 }
 
+void gamgi_gtk_dialog_color_default (GtkWidget *widget, gamgi_window *window)
+{
+GtkWidget *label;
+GtkStyle *style;
+
+/****************************************************
+ * use the default color, taken from the time label *
+ ****************************************************/
+
+label = GTK_STATUSBAR (window->statusbar_time)->label;
+style = gtk_style_copy (gtk_widget_get_style (label));
+gtk_widget_set_style (widget, style);
+g_object_unref (style);
+}
+
 /*************** external function **************
  *                                              *
  *             GAMGI_GTK_DIALOG_BEEP            *
@@ -264,6 +279,18 @@ if (name_color != NULL)
 return button;
 }
 
+void gamgi_gtk_dialog_titles_scan (GtkCellLayout *layout,
+GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, void *data)
+{
+gamgi_bool sensitive;
+
+sensitive = TRUE;
+if (gtk_tree_model_iter_has_child (model, iter) == TRUE)
+  sensitive = FALSE;
+
+g_object_set (renderer, "sensitive", sensitive, NULL);
+}
+
 void gamgi_gtk_dialog_sensitive_scan (GtkCellLayout *layout, 
 GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, void *data)
 {
@@ -355,9 +382,9 @@ gamgi->message = dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 gtk_window_set_title (GTK_WINDOW (dialog), title);
 gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_NONE);
 gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, FALSE, TRUE);
+gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(window->window));
-g_signal_connect (GTK_OBJECT (dialog), "delete_event",
+g_signal_connect (dialog, "delete_event",
 G_CALLBACK (gamgi_gtk_dialog_delete), &gamgi->message);
 
 vbox = gtk_vbox_new (TRUE, 0);
@@ -374,12 +401,11 @@ gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 gtk_widget_show (hbox);
 
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
 gtk_widget_grab_focus (button);
 gtk_widget_show (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_dialog_remove), &gamgi->message);
 
 gtk_widget_show (dialog);
@@ -417,9 +443,9 @@ gamgi->question = dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 gtk_window_set_title (GTK_WINDOW (dialog), title);
 gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_NONE);
 gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, FALSE, TRUE);
+gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(window->window));
-g_signal_connect (GTK_OBJECT (dialog), "delete_event",
+g_signal_connect (dialog, "delete_event",
 G_CALLBACK (gamgi_gtk_dialog_delete), &gamgi->question);
 
 vbox = gtk_vbox_new (FALSE, 0);
@@ -437,19 +463,17 @@ gtk_widget_show (hbox);
 
 button = gamgi_gtk_dialog_button_create ("Ok", NULL);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 gtk_widget_show (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (function_ok), window);
 
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 gtk_widget_grab_focus (button);
 gtk_widget_show (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_dialog_remove), &gamgi->question);
 
 gtk_widget_show (dialog);
@@ -466,8 +490,9 @@ text = gtk_text_view_new ();
 gtk_text_view_set_editable (GTK_TEXT_VIEW (text), FALSE);
 gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (text), FALSE);
 gtk_text_view_set_justification (GTK_TEXT_VIEW (text), GTK_JUSTIFY_LEFT);
+gtk_text_view_set_left_margin (GTK_TEXT_VIEW (text), 10);
+gtk_text_view_set_right_margin (GTK_TEXT_VIEW (text), 10);
 gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (text), GTK_WRAP_WORD);
-
 buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text));
 
 /************************
@@ -612,10 +637,9 @@ while ((windows = windows->next) != NULL);
 window->dialog0 = dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 gtk_window_set_title (GTK_WINDOW (dialog), title);
 gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_NONE);
-gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, FALSE, TRUE);
+gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(window->window));
-
-g_signal_connect_after (GTK_OBJECT (dialog), "delete_event",
+g_signal_connect_after (dialog, "delete_event",
 G_CALLBACK (gamgi_gtk_dialog_task0_delete), window);
 
 return dialog;
@@ -645,10 +669,9 @@ window->dialog1 = dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
 gtk_window_set_title (GTK_WINDOW (dialog), title);
 gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_NONE);
-gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, FALSE, TRUE);
+gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(window->window));
-
-g_signal_connect_after (GTK_OBJECT (dialog), "delete_event",
+g_signal_connect_after (dialog, "delete_event",
 G_CALLBACK (gamgi_gtk_dialog_task1_delete), window);
 
 return dialog;
@@ -678,7 +701,7 @@ GAMGI_GTK_TEXT_WIDTH, GAMGI_GTK_TEXT_HEIGHT);
 gtk_widget_set_size_request (dialog, 
 GAMGI_GTK_TEXT_WIDTH_MIN, GAMGI_GTK_TEXT_HEIGHT_MIN);
 
-g_signal_connect (GTK_OBJECT (dialog), "delete_event",
+g_signal_connect (dialog, "delete_event",
 G_CALLBACK (gamgi_gtk_dialog_delete), &window->help);
 
 return dialog;
@@ -701,12 +724,10 @@ GtkWidget *scrolled_window;
 
 dialog = gamgi_gtk_dialog_task0_create (title, window);
 window->action = action;
-gtk_container_set_border_width (GTK_CONTAINER (dialog), 0);
-gtk_window_set_policy (GTK_WINDOW (dialog), FALSE, TRUE, FALSE);
-
+gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
 gtk_window_set_default_size (GTK_WINDOW (dialog),
 GAMGI_GTK_TEXT_WIDTH, GAMGI_GTK_TEXT_HEIGHT);
-
 gtk_widget_set_size_request (dialog,
 GAMGI_GTK_TEXT_WIDTH_MIN, GAMGI_GTK_TEXT_HEIGHT_MIN);
 
@@ -730,9 +751,8 @@ gtk_widget_show (hbox);
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_dialog_task0_remove), window);
 gtk_widget_show (button);
 
