@@ -419,9 +419,8 @@ GtkWidget *dialog = window->dialog0;
 GtkWidget *button;
 GtkWidget *label;
 GtkWidget *entry;
-GtkWidget *frame;
 GtkWidget *hbox_center, *hbox_left;
-GtkWidget *vbox_page, *vbox_frame, *vbox_top;
+GtkWidget *vbox_page, *vbox_center, *vbox_top;
 
 /*****************
  * Symmetry page *
@@ -430,22 +429,16 @@ GtkWidget *vbox_page, *vbox_frame, *vbox_top;
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Symmetry");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 g_object_set_data (G_OBJECT (dialog), "symmetry_vbox_page", vbox_page);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 15);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /************
@@ -643,7 +636,7 @@ GtkWidget *button;
  ****************/
 
 notebook = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "notebook");
-gtk_notebook_set_page (GTK_NOTEBOOK (notebook), 0);
+gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 0);
 
 /*******************
  * initialize view *
@@ -676,9 +669,8 @@ GtkWidget *dialog = window->dialog0;
 GtkWidget *button;
 GtkWidget *label;
 GtkWidget *entry;
-GtkWidget *frame;
 GtkWidget *hbox_center, *hbox_left, *hbox_left_left;
-GtkWidget *vbox_page, *vbox_frame, *vbox_top;
+GtkWidget *vbox_page, *vbox_center, *vbox_top;
 
 /*******************
  * Reciprocal page *
@@ -687,22 +679,16 @@ GtkWidget *vbox_page, *vbox_frame, *vbox_top;
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Reciprocal");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 g_object_set_data (G_OBJECT (dialog), "reciprocal_vbox_page", vbox_page);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 15);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /******************************************
@@ -768,7 +754,7 @@ gtk_widget_show (entry);
 
 button = gtk_toggle_button_new_with_label ("Bravais");
 gtk_box_pack_end (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_reciprocal_bravais), window);
 g_object_set_data (G_OBJECT (dialog), "reciprocal_button_bravais", button);
 gtk_widget_show (button);
@@ -909,7 +895,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
   cluster->faces = TRUE;
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "voronoi_button_atoms");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
-  cluster->seeds = TRUE;
+  cluster->dots = TRUE;
 
 /********************************
  * get borders combo box option *
@@ -957,9 +943,6 @@ if (window->action == GAMGI_GTK_CLUSTER_MEASURE)
 dialog = gamgi_gtk_dialog_report_create (text, 
 "Measure Voronoi", action, window);
 
-printf ("2: %f %f %f\n", cluster->origin[0], cluster->origin[1], cluster->origin[2]);
-fflush (stdout);
-
 gtk_widget_show (dialog);
 }
 
@@ -1024,12 +1007,11 @@ void gamgi_gtk_measure_voronoi (GtkWidget *notebook, gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *table;
-GtkWidget *frame;
 GtkWidget *button;
 GtkWidget *label;
 GtkWidget *entry;
 GtkWidget *hbox_center, *hbox_left, *hbox_left_left;
-GtkWidget *vbox_page, *vbox_frame, *vbox_top;
+GtkWidget *vbox_page, *vbox_center, *vbox_top;
 GtkWidget *combo;
 GtkListStore *store;
 GtkCellRenderer *renderer;
@@ -1043,22 +1025,16 @@ gamgi_bool *sensitive;
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Voronoi");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 g_object_set_data (G_OBJECT (dialog), "voronoi_vbox_page1", vbox_page);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
-
-vbox_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+vbox_top = gtk_vbox_new (FALSE, 15);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /**************
@@ -1144,22 +1120,16 @@ gtk_widget_show (entry);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Tolerance");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 g_object_set_data (G_OBJECT (dialog), "voronoi_vbox_page2", vbox_page);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /*************
@@ -1218,22 +1188,16 @@ gtk_widget_show (entry);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new (" View ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 g_object_set_data (G_OBJECT (dialog), "voronoi_vbox_page3", vbox_page);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
-
-vbox_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+vbox_top = gtk_vbox_new (FALSE, 15);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /***********************
@@ -1244,7 +1208,7 @@ hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-hbox_left = gtk_hbox_new (FALSE, 15);
+hbox_left = gtk_hbox_new (FALSE, 20);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
@@ -1288,7 +1252,7 @@ renderer, gamgi_gtk_dialog_sensitive_scan, sensitive, free);
 
 button = gtk_toggle_button_new_with_label ("Faces");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_voronoi_faces), window);
 g_object_set_data (G_OBJECT (dialog), "voronoi_button_faces", button);
 gtk_widget_show (button);
@@ -1316,22 +1280,22 @@ gtk_widget_show (table);
 
 button = gtk_toggle_button_new_with_label (" Color ");
 gtk_table_attach (GTK_TABLE (table), button, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_voronoi_color), window);
 g_object_set_data (G_OBJECT (dialog), "voronoi_button_color", button);
 gtk_widget_show (button);
 
-label = gtk_label_new ("r");
+label = gtk_label_new ("R");
 gtk_table_attach (GTK_TABLE (table), label, 2, 3, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
 g_object_set_data (G_OBJECT (dialog), "voronoi_label_red", label);
 gtk_widget_show (label);
 
-label = gtk_label_new ("g");
+label = gtk_label_new ("G");
 gtk_table_attach (GTK_TABLE (table), label, 4, 5, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
 g_object_set_data (G_OBJECT (dialog), "voronoi_label_green", label);
 gtk_widget_show (label);
 
-label = gtk_label_new ("b");
+label = gtk_label_new ("B");
 gtk_table_attach (GTK_TABLE (table), label, 6, 7, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
 g_object_set_data (G_OBJECT (dialog), "voronoi_label_blue", label);
 gtk_widget_show (label);
