@@ -422,6 +422,7 @@ gamgi_object *parent, gamgi_window *window)
 {
 gamgi_window *window_child, *window_parent;
 gamgi_layer *layer_child, *layer_parent;
+GdkWindow *drawable;
 
 /********************************************
  * check if child already belongs to parent *
@@ -540,7 +541,8 @@ gamgi_engine_link_object_object (child, parent);
  * raise to top window and layer where parent object is *
  ********************************************************/
 
-gdk_window_raise (window_parent->window->window);
+drawable = gtk_widget_get_window (window_parent->window);
+gdk_window_raise (drawable);
 if (layer_parent != window_parent->layer)
   {
   gamgi_gtk_object_layer_local (layer_parent, window_parent);
@@ -561,6 +563,7 @@ gamgi_object *parent, gamgi_window *window)
 {
 gamgi_window *window_up = NULL;
 gamgi_layer *layer_up;
+GdkWindow *drawable;
 
 /*****************************************************
  * child: is the last copied object; parent: is the  *
@@ -602,5 +605,6 @@ else if (parent->class == GAMGI_ENGINE_LAYER)
  * raise window containing the copied object to top *
  ****************************************************/
 
-gdk_window_raise (window_up->window->window);
+drawable = gtk_widget_get_window (window_up->window);
+gdk_window_raise (drawable);
 }
