@@ -21,36 +21,24 @@
 #include "gamgi_mesa_select.h"
 #include "gamgi_io_token.h"
 
-static void static_orbital_ok (GtkWidget *widget, void *data)
+void gamgi_gtk_orbital_select (GtkWidget *widget, void *data)
 {
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-
-printf ("handle orbital select ok\n");
-gamgi_gtk_dialog_task0_remove (widget, window);
+printf ("handle orbital select\n");
 }
 
-static void static_arrow_ok (GtkWidget *widget, void *data)
+void gamgi_gtk_arrow_select (GtkWidget *widget, void *data)
 {
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-
-printf ("handle arrow select ok\n");
-gamgi_gtk_dialog_task0_remove (widget, window);
+printf ("handle arrow select\n");
 }
 
-static void static_shape_ok (GtkWidget *widget, void *data)
+void gamgi_gtk_shape_select (GtkWidget *widget, void *data)
 {
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-
-printf ("handle shape select ok\n");
-gamgi_gtk_dialog_task0_remove (widget, window);
+printf ("handle shape select\n");
 }
 
-static void static_graph_ok (GtkWidget *widget, void *data)
+void gamgi_gtk_graph_select (GtkWidget *widget, void *data)
 {
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-
-printf ("handle graph select ok\n");
-gamgi_gtk_dialog_task0_remove (widget, window);
+printf ("handle graph select\n");
 }
 
 void gamgi_gtk_select_mode (char *name, gamgi_window *window)
@@ -772,34 +760,6 @@ while (dlist != NULL)
   gamgi_gtk_select_text (store, &iter, text);
   dlist = dlist->next;
   }
-
-}
-
-void gamgi_gtk_orbital_select (GtkWidget *widget, void *data)
-{
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-GtkWidget *dialog;
-GtkWidget *treeview;
-GtkTreeStore *store;
-gamgi_dlist *dlist;
-
-dialog = gamgi_gtk_dialog_task0_create ("Orbital Select", window);
-window->action = GAMGI_GTK_ORBITAL_SELECT;
-
-treeview = gamgi_gtk_select_dialog (window, static_orbital_ok);
-store = gtk_tree_store_new (2, G_TYPE_STRING, G_TYPE_POINTER);
-
-dlist = gamgi_engine_dlist_orbital_gamgi (NULL);
-while (dlist != NULL)
-  {
-  gamgi_gtk_select_orbital (store, NULL, GAMGI_CAST_ORBITAL dlist->data);
-  dlist = gamgi_engine_dlist_remove_start (dlist);
-  }
-
-gtk_tree_view_set_model (GTK_TREE_VIEW (treeview), GTK_TREE_MODEL (store));
-g_object_unref (store);
-
-gtk_widget_show (dialog);
 }
 
 void gamgi_gtk_select_bond (GtkTreeStore *store,
@@ -1260,33 +1220,6 @@ while (dlist != NULL)
   }
 }
 
-void gamgi_gtk_arrow_select (GtkWidget *widget, void *data)
-{
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-GtkWidget *dialog;
-GtkWidget *treeview;
-GtkTreeStore *store;
-gamgi_dlist *dlist;
-
-dialog = gamgi_gtk_dialog_task0_create ("Arrow Select", window);
-window->action = GAMGI_GTK_ARROW_SELECT;
-
-treeview = gamgi_gtk_select_dialog (window, static_arrow_ok);
-store = gtk_tree_store_new (2, G_TYPE_STRING, G_TYPE_POINTER);
-
-dlist = gamgi_engine_dlist_arrow_gamgi (NULL);
-while (dlist != NULL)
-  {
-  gamgi_gtk_select_arrow (store, NULL, GAMGI_CAST_ARROW dlist->data);
-  dlist = gamgi_engine_dlist_remove_start (dlist);
-  }
-
-gtk_tree_view_set_model (GTK_TREE_VIEW (treeview), GTK_TREE_MODEL (store));
-g_object_unref (store);
-
-gtk_widget_show (dialog);
-}
-
 void gamgi_gtk_select_shape (GtkTreeStore *store,
 GtkTreeIter *iter_parent, gamgi_shape *shape)
 {
@@ -1306,33 +1239,6 @@ while (dlist != NULL)
 
 }
 
-void gamgi_gtk_shape_select (GtkWidget *widget, void *data)
-{
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-GtkWidget *dialog;
-GtkWidget *treeview;
-GtkTreeStore *store;
-gamgi_dlist *dlist;
-
-dialog = gamgi_gtk_dialog_task0_create ("Shape Select", window);
-window->action = GAMGI_GTK_SHAPE_SELECT;
-
-treeview = gamgi_gtk_select_dialog (window, static_shape_ok);
-store = gtk_tree_store_new (2, G_TYPE_STRING, G_TYPE_POINTER);
-
-dlist = gamgi_engine_dlist_shape_gamgi (NULL);
-while (dlist != NULL)
-  {
-  gamgi_gtk_select_shape (store, NULL, GAMGI_CAST_SHAPE dlist->data);
-  dlist = gamgi_engine_dlist_remove_start (dlist);
-  }
-
-gtk_tree_view_set_model (GTK_TREE_VIEW (treeview), GTK_TREE_MODEL (store));
-g_object_unref (store);
-
-gtk_widget_show (dialog);
-}
-
 void gamgi_gtk_select_graph (GtkTreeStore *store,
 GtkTreeIter *iter_parent, gamgi_graph *graph)
 {
@@ -1351,33 +1257,6 @@ while (dlist != NULL)
   }
 }
 
-void gamgi_gtk_graph_select (GtkWidget *widget, void *data)
-{
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-GtkWidget *dialog;
-GtkWidget *treeview;
-GtkTreeStore *store;
-gamgi_dlist *dlist;
-
-dialog = gamgi_gtk_dialog_task0_create ("Graph Select", window);
-window->action = GAMGI_GTK_GRAPH_SELECT;
-
-treeview = gamgi_gtk_select_dialog (window, static_graph_ok);
-store = gtk_tree_store_new (2, G_TYPE_STRING, G_TYPE_POINTER);
-
-dlist = gamgi_engine_dlist_graph_gamgi (NULL);
-while (dlist != NULL)
-  {
-  gamgi_gtk_select_graph (store, NULL, GAMGI_CAST_GRAPH dlist->data);
-  dlist = gamgi_engine_dlist_remove_start (dlist);
-  }
-
-gtk_tree_view_set_model (GTK_TREE_VIEW (treeview), GTK_TREE_MODEL (store));
-g_object_unref (store);
-
-gtk_widget_show (dialog);
-}
-
 void gamgi_gtk_select_assembly (GtkTreeStore *store,
 GtkTreeIter *iter_parent, gamgi_assembly *assembly)
 {
