@@ -350,7 +350,7 @@ if (row != GAMGI_GTK_ALL - 1 && row != GAMGI_GTK_PARTIAL - 1)
   }
 else
   {
-  if (GTK_WIDGET_VISIBLE (vbox) == FALSE)
+  if (gtk_widget_get_visible (vbox) == FALSE)
     {
     static_start_position (window);
 
