@@ -11,6 +11,7 @@
 
 #include "gamgi_engine.h"
 #include "gamgi_gtk.h"
+#include "gamgi_global.h"
 
 #include "gamgi_engine_list.h"
 #include "gamgi_engine_find.h"
@@ -22,6 +23,7 @@
 #include "gamgi_gtk_object.h"
 #include "gamgi_mesa_select.h"
 #include "gamgi_io_token.h"
+#include "gamgi_global_selection.h"
 
 static void static_clean (gamgi_window *window)
 {
@@ -63,15 +65,15 @@ combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 }
 
-/********************** internal function ****************
- *                                                       *
- *                       STATIC_GLOBAL                   *
- *                                                       *
- * When the global button is on, disable the group entry *
- * and reset dialog, otherwise, enable the group entry.  *        
- *********************************************************/
+/********************** internal function ***************
+ *                                                      *
+ *                       STATIC_LIST                    *
+ *                                                      *
+ * When the List button is on, disable the group entry  *
+ * and reset dialog, otherwise, enable the group entry. *
+ ********************************************************/
 
-static void static_global (GtkWidget *widget, void *data)
+static void static_list (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
@@ -79,7 +81,7 @@ GtkWidget *hbox;
 GtkWidget *button;
 
 hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_group");
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   {
@@ -100,15 +102,12 @@ else
   }
 }
 
-static void static_apply (gamgi_group *group, gamgi_window *window)
+static void static_apply (gamgi_group *group, int scope, gamgi_window *window)
 {
 gamgi_atom *atom;
 gamgi_bond *bond;
 gamgi_object *parent;
 gamgi_dlist *dlist, *dlist_b;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *combo;
-int row;
 
 /*****************************************************
  * Remove group data according to Scope combo box:   *
@@ -119,14 +118,11 @@ int row;
  * 4) Child: Remove the child list of a given class; *
  *****************************************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
 /******************************************
  * All: remove group and all its contents *
  *****************************************/
 
-if (row == 0)
+if (scope == 0)
   {
   gamgi_engine_unlink_group (group);
   gamgi_engine_remove_group (group);
@@ -136,7 +132,7 @@ if (row == 0)
  * Container: link contents to group parent and remove group *
  *************************************************************/
 
-if (row == 1)
+if (scope == 1)
   {
   parent = group->object.object;
   gamgi_engine_reparent_group (group->group_start, parent);
@@ -153,7 +149,7 @@ if (row == 1)
  * Contents: remove all child objects in group *
  ***********************************************/
 
-if (row == 2)
+if (scope == 2)
   {
   dlist = group->group_start;
   while (dlist != NULL)
@@ -202,7 +198,7 @@ if (row == 2)
  * Group: remove group list in group *
  *************************************/
 
-if (row == 3)
+if (scope == 3)
   {
   dlist = group->group_start;
   while (dlist != NULL)
@@ -216,7 +212,7 @@ if (row == 3)
  * Plane: remove plane list in group *
  *************************************/
 
-if (row == 4)
+if (scope == 4)
   {
   dlist = group->plane_start;
   while (dlist != NULL)
@@ -230,7 +226,7 @@ if (row == 4)
  * Direction: remove direction list in group *
  *********************************************/
 
-if (row == 5)
+if (scope == 5)
   {
   dlist = group->direction_start;
   while (dlist != NULL)
@@ -244,7 +240,7 @@ if (row == 5)
  * Atom: remove atom list in group *
  ***********************************/
 
-if (row == 6)
+if (scope == 6)
   {
   dlist = group->atom_start;
   while (dlist != NULL)
@@ -258,7 +254,7 @@ if (row == 6)
  * Bond: remove bond list in atom list in group *
  ************************************************/
 
-if (row == 7)
+if (scope == 7)
   {
   dlist = group->atom_start;
   while (dlist != NULL)
@@ -281,7 +277,7 @@ if (row == 7)
  * Orbital: remove orbital list in group *
  *****************************************/
 
-if (row == 8)
+if (scope == 8)
   {
   dlist = group->orbital_start;
   while (dlist != NULL)
@@ -295,7 +291,7 @@ if (row == 8)
  * Text: remove text list in group *
  ***********************************/
 
-if (row == 9)
+if (scope == 9)
   {
   dlist = group->text_start;
   while (dlist != NULL)
@@ -307,57 +303,135 @@ if (row == 9)
 
 }
 
+static void static_ok_global (int scope, gamgi_window *window)
+{
+gamgi_dlist *dlist, *groups;
+
+if (gamgi->groups == NULL)
+  { gamgi_gtk_dialog_message_create ("Error",
+  "Empty list of group objects", window); return; }
+
+/************************************************
+ * for all windows: save layers as undo layers, *
+ * set current layer as new current object      *
+ ************************************************/
+
+gamgi_global_selection_undo ();
+gamgi_global_selection_focus ();
+
+/*********************************************************
+ * disable automatic mechanism to remove selection list, *
+ * so we can scan the list and remove it only in the end *
+ *********************************************************/
+
+groups = gamgi->groups;
+gamgi->groups = NULL;
+
+/*********************************************************
+ *   remove group data as specified in scope combo box   *
+ *                                                       *
+ * groups are recursive objects: a group may recursively *
+ * remove a child of the same class that appears later   *
+ * in the list: listed objects that were already         *
+ * removed will have a list node pointing to NULL        *
+ *********************************************************/
+
+for (dlist = groups; dlist != NULL; dlist = dlist->next)
+  if (dlist->data != NULL)
+    static_apply (GAMGI_CAST_GROUP dlist->data, scope, window);
+
+/******************************************************
+ * remove the selection list of a class of objects    *
+ * only when objects of that class are really removed *
+ ******************************************************/
+
+gamgi->groups = groups;
+if (scope < 4)
+  gamgi_global_selection_remove (&gamgi->groups, "button_group");
+
+/*****************************************
+ * For all windows: redraw gl_area image *
+ *****************************************/
+
+gamgi_global_selection_draw ();
+}
+
+static void static_ok_local (int scope, gamgi_window *window)
+{
+gamgi_group *group;
+GtkWidget *dialog = window->dialog0;
+
+/***************
+ * Pick object *
+ ***************/
+
+group = GAMGI_CAST_GROUP gamgi_gtk_object_name_number (dialog,
+"entry_group", GAMGI_ENGINE_GROUP, window);
+if (group == NULL)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid group object", window);
+  return;
+  }
+
+/*************************************************
+ * Before removing the group, check if the       *
+ * current object is affected. In this case, the *
+ * current layer becomes the new current object. *
+ *************************************************/
+
+if (gamgi_engine_find_object (window->focus,
+GAMGI_CAST_OBJECT group) == TRUE)
+  gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
+
+/***************************************
+ * Save current layer as undo buffer   *
+ * layer so it can be recovered later. *
+ ***************************************/
+
+gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
+
+/**************************************************
+ * remove group data as chosen in scope combo box *
+ **************************************************/
+
+static_apply (group, scope, window);
+
+/**********************************************
+ * Redraw gl_area image and reset group entry *
+ **********************************************/
+
+gtk_widget_queue_draw (window->area);
+}
+
 static void static_ok (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
-gamgi_group *group;
 GtkWidget *dialog = window->dialog0;
 GtkWidget *button;
+GtkWidget *combo;
+int scope;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
-  {
-  /***************
-   * Pick method *
-   ***************/
+/*********************************************************
+ * get dialog data common to both local and global tasks *
+ *********************************************************/
 
-  group = GAMGI_CAST_GROUP gamgi_gtk_object_name_number (dialog,
-  "entry_group", GAMGI_ENGINE_GROUP, window);
-  if (group == NULL)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid group object", window);
-    return;
-    }
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
+scope = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
-  /*************************************************
-   * Before removing the group, check if the       *
-   * current object is affected. In this case, the *
-   * current layer becomes the new current object. *
-   *************************************************/
+/********************************
+ * execute global or local task *
+ ********************************/
 
-  if (gamgi_engine_find_object (window->focus,
-  GAMGI_CAST_OBJECT group) == TRUE)
-    gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  static_ok_global (scope, window);
+else
+  static_ok_local (scope, window);
 
-  /***************************************
-   * Save current layer as undo buffer   *
-   * layer so it can be recovered later. *
-   ***************************************/
+/***********************************************************
+ * clean dialog data common to both local and global tasks *
+ ***********************************************************/
 
-  gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
-
-  /**************************************************
-   * remove group data as chosen in scope combo box *
-   **************************************************/
-
-  static_apply (group, window);
-  }
-
-/*********************************************
- * Redraw gl_area image and reset text entry *
- *********************************************/
-
-gtk_widget_queue_draw (window->area);
 static_clean (window);
 }
 
@@ -404,7 +478,7 @@ GtkWidget *button;
  * local mouse selection only *
  ******************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE ||
 window_dialog != window_mouse) return;
 
@@ -482,15 +556,15 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 g_object_set_data (G_OBJECT (dialog), "entry_group", entry);
 gtk_widget_show (entry);
 
-/**********
- * Global *
- **********/
+/********
+ * List *
+ ********/
 
-button = gtk_toggle_button_new_with_label ("Global");
+button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "toggled",
-G_CALLBACK (static_global), window);
-g_object_set_data (G_OBJECT (dialog), "button_global", button);
+G_CALLBACK (static_list), window);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /************
