@@ -277,7 +277,7 @@ gtk_widget_set_size_request (combo_below, width, height);
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_below");
 gtk_button_clicked (GTK_BUTTON (button));
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_link");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_method");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 
 /***************************************************
@@ -321,7 +321,7 @@ gtk_entry_set_text (GTK_ENTRY (entry), string);
  ****************************************************/
 
 void gamgi_gtk_layer_link_press (gamgi_window *window_mouse,
-int x, int y, gamgi_window *window_dialog)
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 {
 GtkWidget *dialog = window_dialog->dialog0;
 GtkWidget *button;
@@ -366,9 +366,8 @@ GtkWidget *notebook;
 GtkWidget *button;
 GtkWidget *label;
 GtkWidget *entry;
-GtkWidget *frame;
 GtkWidget *hbox_center, *hbox_left, *hbox_left_left;
-GtkWidget *vbox_dialog, *vbox_page, *vbox_frame, *vbox_top, *vbox_top_top;
+GtkWidget *vbox_dialog, *vbox_page, *vbox_center, *vbox_top, *vbox_top_top;
 GtkWidget *combo;
 GtkListStore *store;
 GtkCellRenderer *renderer;
@@ -428,8 +427,7 @@ gtk_widget_show (entry);
 
 button = gtk_toggle_button_new_with_label ("Global");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "toggled",
-G_CALLBACK (static_global), window);
+g_signal_connect (button, "toggled", G_CALLBACK (static_global), window);
 g_object_set_data (G_OBJECT (dialog), "button_global", button);
 gtk_widget_show (button);
 
@@ -450,21 +448,15 @@ gtk_widget_show (notebook);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Object");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 15);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 vbox_top_top = gtk_vbox_new (FALSE, 5);
@@ -484,21 +476,19 @@ gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
 label = gtk_label_new ("Hierarchy");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
 button = gtk_radio_button_new_with_label (NULL, "Above");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0); 
-g_signal_connect (GTK_OBJECT (button), "clicked",
-G_CALLBACK (static_hierarchy), window);
+g_signal_connect (button, "clicked", G_CALLBACK (static_hierarchy), window);
 g_object_set_data (G_OBJECT (dialog), "button_above", button);
 gtk_widget_show (button);
 
 button = gtk_radio_button_new_with_label (
 gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)), "Below");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
-G_CALLBACK (static_hierarchy), window);
+g_signal_connect (button, "clicked", G_CALLBACK (static_hierarchy), window);
 g_object_set_data (G_OBJECT (dialog), "button_below", button);
 gtk_widget_show (button);
 
@@ -577,9 +567,9 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 g_object_set_data (G_OBJECT (dialog), "entry_object", entry);
 gtk_widget_show (entry);
 
-/********
- * link *
- ********/
+/**********
+ * method *
+ **********/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
@@ -589,13 +579,13 @@ hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-label = gtk_label_new ("Link");
+label = gtk_label_new ("Method");
 gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "combo_link", combo);
+g_object_set_data (G_OBJECT (dialog), "combo_method", combo);
 gtk_widget_show (combo);
 
 renderer = gtk_cell_renderer_text_new ();
@@ -619,17 +609,14 @@ gtk_widget_show (hbox_center);
 button = gamgi_gtk_dialog_button_create ("Ok", NULL);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-g_signal_connect (GTK_OBJECT (button), "clicked",
-G_CALLBACK (static_ok), window);
+g_signal_connect (button, "clicked", G_CALLBACK (static_ok), window);
 gtk_widget_show (button);
 
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_dialog_task0_remove), window);
 gtk_widget_show (button);
 
