@@ -448,8 +448,8 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
 
   entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
   name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &scale, 0.0, DBL_MAX) == FALSE)
+  if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_double_scan (name,
+  &scale, GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
     {
     gamgi_gtk_dialog_message_create ("Error", "Invalid Scale Data", window);
     return;
@@ -696,7 +696,7 @@ gtk_entry_set_text (GTK_ENTRY (entry), string);
  ***********************************************/
 
 void gamgi_gtk_layer_modify_press (gamgi_window *window_mouse,
-int x, int y, gamgi_window *window_dialog)
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 {
 GtkWidget *dialog = window_dialog->dialog0;
 GtkWidget *button;
@@ -726,10 +726,9 @@ void gamgi_gtk_layer_modify (GtkWidget *widget, void *data)
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog;
 GtkWidget *notebook;
-GtkWidget *frame;
 GtkWidget *table;
 GtkWidget *hbox_center, *hbox_left, *hbox_left_left;
-GtkWidget *vbox_dialog, *vbox_page, *vbox_frame, *vbox_top;
+GtkWidget *vbox_dialog, *vbox_page, *vbox_center, *vbox_top;
 GtkWidget *button;
 GtkWidget *label;
 GtkWidget *entry;
@@ -792,7 +791,7 @@ gtk_widget_show (entry);
 
 button = gtk_toggle_button_new_with_label ("Global");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "toggled",
+g_signal_connect (button, "toggled",
 G_CALLBACK (static_global), window);
 g_object_set_data (G_OBJECT (dialog), "button_global", button);
 gtk_widget_show (button);
@@ -814,21 +813,15 @@ gtk_widget_show (notebook);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Projection");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /**************
@@ -839,8 +832,16 @@ hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
+hbox_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left);
+
+label = gtk_label_new ("Type");
+gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
+
 combo = gtk_combo_box_new ();
-gtk_box_pack_start (GTK_BOX (hbox_center), combo, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
 g_object_set_data (G_OBJECT (dialog), "combo_projection", combo);
 gtk_widget_show (combo);
 
@@ -911,21 +912,15 @@ gtk_widget_show (entry);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Position");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 /*******************
@@ -1031,21 +1026,15 @@ gtk_widget_show (entry);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Visibility");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 table = gtk_table_new (2, 2, FALSE);
@@ -1118,21 +1107,15 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new (" View ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 20);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /***********
@@ -1260,18 +1243,16 @@ gtk_widget_show (hbox_center);
 
 button = gamgi_gtk_dialog_button_create ("Ok", NULL);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_ok), window);
 gtk_widget_show (button);
 
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_dialog_task0_remove), window);
 gtk_widget_show (button);
 
