@@ -11,6 +11,7 @@
 
 #include "gamgi_engine.h"
 #include "gamgi_gtk.h"
+#include "gamgi_global.h"
 
 #include "gamgi_engine_list.h"
 #include "gamgi_engine_find.h"
@@ -22,6 +23,7 @@
 #include "gamgi_gtk_object.h"
 #include "gamgi_mesa_select.h"
 #include "gamgi_io_token.h"
+#include "gamgi_global_selection.h"
 
 static void static_clean (gamgi_window *window)
 {
@@ -63,15 +65,15 @@ combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 }
 
-/**********************internal function *****************
- *                                                       *
- *                       STATIC_GLOBAL                   *
- *                                                       *
- * When the global button is on, disable the layer entry *
- * and reset dialog, otherwise, enable the layer entry.  *        
- *********************************************************/
+/**********************internal function ****************
+ *                                                      *
+ *                       STATIC_LIST                    *
+ *                                                      *
+ * When the List button is on, disable the layer entry  *
+ * and reset dialog, otherwise, enable the layer entry. *
+ ********************************************************/
 
-static void static_global (GtkWidget *widget, void *data)
+static void static_list (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
@@ -79,7 +81,7 @@ GtkWidget *hbox;
 GtkWidget *button;
 
 hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_layer");
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   {
@@ -100,14 +102,12 @@ else
   }
 }
 
-static void static_apply (gamgi_layer *layer, gamgi_window *window)
+static void static_apply (gamgi_layer *layer, int scope,
+gamgi_window *window)
 {
 gamgi_atom *atom;
 gamgi_bond *bond;
 gamgi_dlist *dlist, *dlist_b;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *combo;
-int row;
 
 /*****************************************************
  * Remove layer data according to Scope menu:        *
@@ -116,42 +116,21 @@ int row;
  * 3) Child: Remove the child list of a given class; *
  *****************************************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
 /******************************************
  * All: remove layer and all its contents *
  ******************************************/
 
-if (row == 0)
+if (scope == 0)
   {
-  /*********************************************
-   * If layer is the current layer, then a new *
-   * current layer (and object) must be found. *
-   *********************************************/
-
-  if (layer == window->layer)
-    gamgi_gtk_object_layer_current (layer, window);
-
   gamgi_engine_unlink_layer (layer);
   gamgi_engine_remove_layer (layer);
   }
-else
-  {
-  /***************************************
-   * If layer is the current layer, then *
-   * it becomes also the current object  *
-   ***************************************/
-
-  if (layer == window->layer)
-    gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT layer, window);
-  }
 
 /***********************************************
  * Contents: remove all child objects in layer *
  ***********************************************/
 
-if (row == 1)
+if (scope == 1)
   {
   dlist = layer->light_start;
   while (dlist != NULL)
@@ -235,7 +214,7 @@ if (row == 1)
  * Light: remove light list in layer *
  *************************************/
 
-if (row == 2)
+if (scope == 2)
   {
   dlist = layer->light_start;
   while (dlist != NULL)
@@ -249,7 +228,7 @@ if (row == 2)
  * Assembly: remove assembly list in layer *
  *******************************************/
 
-if (row == 3)
+if (scope == 3)
   {
   dlist = layer->assembly_start;
   while (dlist != NULL)
@@ -263,7 +242,7 @@ if (row == 3)
  * Cell: remove cell list in layer *
  ***********************************/
 
-if (row == 4)
+if (scope == 4)
   {
   dlist = layer->cell_start;
   while (dlist != NULL)
@@ -277,7 +256,7 @@ if (row == 4)
  * Cluster: remove cluster list in layer *
  *****************************************/
 
-if (row == 5)
+if (scope == 5)
   {
   dlist = layer->cluster_start;
   while (dlist != NULL)
@@ -291,7 +270,7 @@ if (row == 5)
  * Molecule: remove molecule list in layer *
  *******************************************/
 
-if (row == 6)
+if (scope == 6)
   {
   dlist = layer->molecule_start;
   while (dlist != NULL)
@@ -305,7 +284,7 @@ if (row == 6)
  * Group: remove group list in layer *
  *************************************/
 
-if (row == 7)
+if (scope == 7)
   {
   dlist = layer->group_start;
   while (dlist != NULL)
@@ -319,7 +298,7 @@ if (row == 7)
  * Plane: remove plane list in layer *
  *************************************/
 
-if (row == 8)
+if (scope == 8)
   {
   dlist = layer->plane_start;
   while (dlist != NULL)
@@ -333,7 +312,7 @@ if (row == 8)
  * Direction: remove direction list in layer *
  *********************************************/
 
-if (row == 9)
+if (scope == 9)
   {
   dlist = layer->direction_start;
   while (dlist != NULL)
@@ -347,7 +326,7 @@ if (row == 9)
  * Atom: remove atom list in layer *
  ***********************************/
 
-if (row == 10)
+if (scope == 10)
   {
   dlist = layer->atom_start;
   while (dlist != NULL)
@@ -361,7 +340,7 @@ if (row == 10)
  * Bond: remove bond list in atom list in layer *
  ************************************************/
 
-if (row == 11)
+if (scope == 11)
   {
   dlist = layer->atom_start;
   while (dlist != NULL)
@@ -384,7 +363,7 @@ if (row == 11)
  * Orbital: remove orbital list in layer *
  *****************************************/
 
-if (row == 12)
+if (scope == 12)
   {
   dlist = layer->orbital_start;
   while (dlist != NULL)
@@ -398,7 +377,7 @@ if (row == 12)
  * Text: remove text list in layer *
  ***********************************/
 
-if (row == 13)
+if (scope == 13)
   {
   dlist = layer->text_start;
   while (dlist != NULL)
@@ -410,9 +389,78 @@ if (row == 13)
 
 }
 
-static void static_ok (GtkWidget *widget, void *data)
+static void static_ok_global (int scope, gamgi_window *window)
+{
+gamgi_window *parent;
+gamgi_layer *layer;
+gamgi_dlist *dlist, *layers;
+
+if (gamgi->layers == NULL)
+  { gamgi_gtk_dialog_message_create ("Error",
+  "Empty list of layer objects", window); return; }
+
+/************************************************
+ * For all windows: save layers as undo layers, *
+ * set current layer as new current object      *
+ ************************************************/
+
+if (scope > 0)
+  {
+  gamgi_global_selection_undo ();
+  gamgi_global_selection_focus ();
+  }
+
+/*********************************************************
+ * disable automatic mechanism to remove selection list, *
+ * so we can scan the list and remove it only in the end *
+ *********************************************************/
+
+layers = gamgi->layers;
+gamgi->layers = NULL;
+
+/*****************************************************
+ * remove layer data as specified in scope combo box *
+ *****************************************************/
+
+for (dlist = layers; dlist != NULL; dlist = dlist->next)
+  {
+  /*************************************************************
+   * If layer is the current layer:                            *
+   * scope = 0: a new current layer (and object) must be found *
+   * scope = 1: the layer becomes also the current object      *
+   *************************************************************/
+
+  layer = GAMGI_CAST_LAYER dlist->data;
+  parent = GAMGI_CAST_WINDOW layer->object.object;
+  if (layer == parent->layer)
+    {
+    if (scope == 0)
+      gamgi_gtk_object_layer_current (layer, parent);
+    else
+      gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT layer, parent);
+    }
+
+  static_apply (layer, scope, window);
+  }
+
+/******************************************************
+ * remove the selection list of a class of objects    *
+ * only when objects of that class are really removed *
+ ******************************************************/
+
+gamgi->layers = layers;
+if (scope < 1)
+  gamgi_global_selection_remove (&gamgi->layers, "button_layer");
+
+/*****************************************
+ * For all windows: redraw gl_area image *
+ *****************************************/
+
+gamgi_global_selection_draw ();
+}
+
+static void static_ok_local (int scope, gamgi_window *window)
 {
-gamgi_window *window = GAMGI_CAST_WINDOW data;
 gamgi_layer *layer;
 GtkWidget *dialog = window->dialog0;
 
@@ -424,17 +472,62 @@ if (layer == NULL)
   return;
   }
 
+/*************************************************************
+ * If layer is the current layer:                            *
+ * scope = 0: a new current layer (and object) must be found *
+ * scope = 1: the layer becomes also the current object      *
+ *************************************************************/
+
+if (layer == window->layer)
+  {
+  if (scope == 0)
+    gamgi_gtk_object_layer_current (layer, window);
+  else
+    gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT layer, window);
+  }
+
 /*********************************************
  * remove layer data as chosen in scope menu *
  *********************************************/
 
-static_apply (layer, window);
+static_apply (layer, scope, window);
 
-/**********************************************
- * Redraw gl_area image and reset layer entry *
- **********************************************/
+/************************
+ * redraw gl_area image *
+ ************************/
 
 gtk_widget_queue_draw (window->area);
+}
+
+static void static_ok (GtkWidget *widget, void *data)
+{
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *button;
+GtkWidget *combo;
+int scope;
+
+/*********************************************************
+ * get dialog data common to both local and global tasks *
+ *********************************************************/
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
+scope = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+
+/********************************
+ * execute global or local task *
+ ********************************/
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  static_ok_global (scope, window);
+else
+  static_ok_local (scope, window);
+
+/***********************************************************
+ * clean dialog data common to both local and global tasks *
+ ***********************************************************/
+
 static_clean (window);
 }
 
@@ -493,7 +586,7 @@ GtkWidget *button;
  * local mouse selection only *
  ******************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE ||
 window_dialog != window_mouse) return;
 
@@ -571,15 +664,15 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 g_object_set_data (G_OBJECT (dialog), "entry_layer", entry);
 gtk_widget_show (entry);
 
-/**********
- * Global *
- **********/
+/********
+ * List *
+ ********/
 
-button = gtk_toggle_button_new_with_label ("Global");
+button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "toggled",
-G_CALLBACK (static_global), window);
-g_object_set_data (G_OBJECT (dialog), "button_global", button);
+G_CALLBACK (static_list), window);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /************
