@@ -1164,21 +1164,21 @@ static_reset (window);
 static void static_init (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
-GtkWidget *notebook;
+GtkWidget *vbox;
 GtkWidget *combo;
 GtkRequisition size;
 
 /***************************************************
- * Set notebook current size as its maximum size:  *
+ * Set vbox_top current size as its maximum size:  *
  * this is needed because different methods need   *
- * different wdiths, changing the dialog width.    *
+ * different widths, changing the dialog width.    *
  * Fixing the dialog size only partly solves the   *
  * problem because the page size can still change. *
  ***************************************************/
 
-notebook = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "notebook");
-gtk_widget_size_request (GTK_WIDGET (notebook), &size);
-gtk_widget_set_size_request (notebook, size.width, size.height);
+vbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_top");
+gtk_widget_size_request (GTK_WIDGET (vbox), &size);
+gtk_widget_set_size_request (vbox, size.width, size.height);
 
 /**************************************************
  * everytime the dialog is created: initialize    *
@@ -1367,6 +1367,7 @@ gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview), FALSE);
 
 vbox_top = gtk_vbox_new (FALSE, 20);
 gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "vbox_top", vbox_top);
 gtk_widget_show (vbox_top);
 
 /*********
@@ -1377,20 +1378,20 @@ vbox_top_top = gtk_vbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (vbox_top), vbox_top_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top_top);
 
-hbox_center = gtk_hbox_new (TRUE, 0);
+hbox_center = gtk_hbox_new (TRUE, 5);
 gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left);
-
 label = gtk_label_new ("Scope");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (hbox_center), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
+hbox_center = gtk_hbox_new (TRUE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_center, FALSE, FALSE, 0);
+gtk_widget_show (hbox_center);
+
 combo = gtk_combo_box_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (hbox_center), combo, FALSE, FALSE, 0);
 g_signal_connect (combo, "changed", G_CALLBACK (static_scope), window);
 g_object_set_data (G_OBJECT (dialog), "combo_scope", combo);
 gtk_widget_show (combo);
@@ -1419,20 +1420,20 @@ vbox_top_top = gtk_vbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (vbox_top), vbox_top_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top_top);
 
-hbox_center = gtk_hbox_new (TRUE, 0);
+hbox_center = gtk_hbox_new (TRUE, 5);
 gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left);
-
 label = gtk_label_new ("Action");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (hbox_center), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
+hbox_center = gtk_hbox_new (TRUE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_center, FALSE, FALSE, 0);
+gtk_widget_show (hbox_center);
+
 combo = gtk_combo_box_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (hbox_center), combo, FALSE, FALSE, 0);
 g_object_set_data (G_OBJECT (dialog), "combo_action", combo);
 gtk_widget_show (combo);
 
@@ -1456,20 +1457,20 @@ vbox_top_top = gtk_vbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (vbox_top), vbox_top_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top_top);
 
-hbox_center = gtk_hbox_new (TRUE, 0);
+hbox_center = gtk_hbox_new (TRUE, 5);
 gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left);
-
 label = gtk_label_new ("Method");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (hbox_center), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
+hbox_center = gtk_hbox_new (TRUE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_center, FALSE, FALSE, 0);
+gtk_widget_show (hbox_center);
+
 combo = gtk_combo_box_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (hbox_center), combo, FALSE, FALSE, 0);
 g_signal_connect (combo, "changed", G_CALLBACK (static_method), window);
 g_object_set_data (G_OBJECT (dialog), "combo_method", combo);
 gtk_widget_show (combo);
