@@ -11,6 +11,7 @@
 
 #include "gamgi_engine.h"
 #include "gamgi_gtk.h"
+#include "gamgi_global.h"
 
 #include "gamgi_engine_list.h"
 #include "gamgi_engine_find.h"
@@ -22,6 +23,7 @@
 #include "gamgi_gtk_object.h"
 #include "gamgi_mesa_select.h"
 #include "gamgi_io_token.h"
+#include "gamgi_global_selection.h"
 
 static void static_clean (gamgi_window *window)
 {
@@ -63,15 +65,15 @@ combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 }
 
-/********************* internal function *****************
- *                                                       *
- *                       STATIC_GLOBAL                   *
- *                                                       *
- * When the global button is on, disable the light entry *
- * and reset dialog, otherwise, enable the light entry.  *        
- *********************************************************/
+/********************* internal function ****************
+ *                                                      *
+ *                       STATIC_LIST                    *
+ *                                                      *
+ * When the List button is on, disable the light entry  *
+ * and reset dialog, otherwise, enable the light entry. *
+ ********************************************************/
 
-static void static_global (GtkWidget *widget, void *data)
+static void static_list (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
@@ -79,7 +81,7 @@ GtkWidget *hbox;
 GtkWidget *button;
 
 hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_light");
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   {
@@ -100,25 +102,18 @@ else
   }
 }
 
-static void static_apply (gamgi_light *light, gamgi_window *window)
+static void static_apply (gamgi_light *light, int scope, gamgi_window *window)
 {
-GtkWidget *dialog = window->dialog0;
-GtkWidget *combo;
-int row;
-
 /**********************************************
  * Remove light data according to Scope menu: *
  * 1) All: remove light and all its contents; *
  **********************************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
 /******************************************
  * All: remove light and all its contents *
  ******************************************/
 
-if (row == 0)
+if (scope == 0)
   {
   gamgi_engine_unlink_light (light);
   gamgi_engine_remove_light (light);
@@ -126,57 +121,129 @@ if (row == 0)
 
 }
 
-static void static_ok (GtkWidget *widget, void *data)
+static void static_ok_global (int scope, gamgi_window *window)
+{
+gamgi_dlist *dlist, *lights;
+
+if (gamgi->lights == NULL)
+  { gamgi_gtk_dialog_message_create ("Error",
+  "Empty list of light objects", window); return; }
+
+/************************************************
+ * for all windows: save layers as undo layers, *
+ * set current layer as new current object      *
+ ************************************************/
+
+gamgi_global_selection_undo ();
+gamgi_global_selection_focus ();
+
+/*********************************************************
+ * disable automatic mechanism to remove selection list, *
+ * so we can scan the list and remove it only in the end *
+ *********************************************************/
+
+lights = gamgi->lights;
+gamgi->lights = NULL;
+
+/*****************************************************
+ * remove light data as specified in scope combo box *
+ *****************************************************/
+
+for (dlist = lights; dlist != NULL; dlist = dlist->next)
+  static_apply (GAMGI_CAST_LIGHT dlist->data, scope, window);
+
+/******************************************************
+ * remove the selection list of a class of objects    *
+ * only when objects of that class are really removed *
+ ******************************************************/
+
+gamgi->lights = lights;
+if (scope < 1)
+  gamgi_global_selection_remove (&gamgi->lights, "button_light");
+
+/*****************************************
+ * For all windows: redraw gl_area image *
+ *****************************************/
+
+gamgi_global_selection_draw ();
+}
+
+static void static_ok_local (int scope, gamgi_window *window)
 {
-gamgi_window *window = GAMGI_CAST_WINDOW data;
 gamgi_light *light;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *button;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
+/***************
+ * Pick object *
+ ***************/
+
+light = GAMGI_CAST_LIGHT gamgi_gtk_object_name_number (dialog,
+"entry_light", GAMGI_ENGINE_LIGHT, window);
+if (light == NULL)
   {
-  /***************
-   * Pick method *
-   ***************/
-
-  light = GAMGI_CAST_LIGHT gamgi_gtk_object_name_number (dialog,
-  "entry_light", GAMGI_ENGINE_LIGHT, window);
-  if (light == NULL)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid light object", window);
-    return;
-    }
-
-  /*************************************************
-   * Before removing the light, check if the       *
-   * current object is affected. In this case, the *
-   * current layer becomes the new current object. *
-   *************************************************/
-
-  if (gamgi_engine_find_object (window->focus,
-  GAMGI_CAST_OBJECT light) == TRUE)
-    gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
-
-  /***************************************
-   * Save current layer as undo buffer   *
-   * layer so it can be recovered later. *
-   ***************************************/
-
-  gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
-
-  /**************************************************
-   * remove light data as chosen in scope combo box *
-   **************************************************/
-
-  static_apply (light, window);
+  gamgi_gtk_dialog_message_create ("Error", "Invalid light object", window);
+  return;
   }
 
+/*************************************************
+ * Before removing the light, check if the       *
+ * current object is affected. In this case, the *
+ * current layer becomes the new current object. *
+ *************************************************/
+
+if (gamgi_engine_find_object (window->focus,
+GAMGI_CAST_OBJECT light) == TRUE)
+  gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
+
+/***************************************
+ * Save current layer as undo buffer   *
+ * layer so it can be recovered later. *
+ ***************************************/
+
+gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
+
+/**************************************************
+ * remove light data as chosen in scope combo box *
+ **************************************************/
+
+static_apply (light, scope, window);
+
 /**********************************************
  * Redraw gl_area image and reset light entry *
  **********************************************/
 
 gtk_widget_queue_draw (window->area);
+}
+
+static void static_ok (GtkWidget *widget, void *data)
+{
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *button;
+GtkWidget *combo;
+int scope;
+
+/*********************************************************
+ * get dialog data common to both local and global tasks *
+ *********************************************************/
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
+scope = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+
+/********************************
+ * execute global or local task *
+ ********************************/
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  static_ok_global (scope, window);
+else
+  static_ok_local (scope, window);
+
+/***********************************************************
+ * clean dialog data common to both local and global tasks *
+ ***********************************************************/
+
 static_clean (window);
 }
 
@@ -223,7 +290,7 @@ GtkWidget *button;
  * local mouse selection only *
  ******************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE ||
 window_dialog != window_mouse) return;
 
@@ -308,8 +375,8 @@ gtk_widget_show (entry);
 button = gtk_toggle_button_new_with_label ("Global");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "toggled",
-G_CALLBACK (static_global), window);
-g_object_set_data (G_OBJECT (dialog), "button_global", button);
+G_CALLBACK (static_list), window);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /************
