@@ -610,7 +610,7 @@ if (row == GAMGI_GTK_NONE - 1) plane->autonomy = GAMGI_GTK_NONE;
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_thickness");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE &&
+if (gtk_widget_is_sensitive (entry) == TRUE &&
 gamgi_io_token_double_scan (name, &plane->thickness, 
 GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
   {
@@ -634,7 +634,7 @@ if (cell == NULL) return TRUE;
 *start = -INT_MAX;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_start");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE &&
+if (gtk_widget_is_sensitive (entry) == TRUE &&
 gamgi_io_token_int_scan (name, start, -INT_MAX, INT_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Plane Order", window);
@@ -645,7 +645,7 @@ gamgi_io_token_int_scan (name, start, -INT_MAX, INT_MAX) == FALSE)
 *end = INT_MAX;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_end");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE &&
+if (gtk_widget_is_sensitive (entry) == TRUE &&
 gamgi_io_token_int_scan (name, end, -INT_MAX, INT_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Plane Order", window);
