@@ -24,6 +24,7 @@
 #include "gamgi_mesa_select.h"
 #include "gamgi_chem_atom.h"
 #include "gamgi_io_token.h"
+#include "gamgi_global_selection.h"
 
 static void static_clean (gamgi_window *window)
 {
@@ -65,15 +66,15 @@ combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 }
 
-/*********************** internal function ***************
- *                                                       *
- *                         STATIC_GLOBAL                 *
- *                                                       *
- * When the global button is on, disable the plane entry *
- * and reset dialog, otherwise, enable the plane entry.  *        
- *********************************************************/
+/*********************** internal function **************
+ *                                                      *
+ *                         STATIC_LIST                  *
+ *                                                      *
+ * When the List button is on, disable the plane entry  *
+ * and reset dialog, otherwise, enable the plane entry. *
+ ********************************************************/
 
-static void static_global (GtkWidget *widget, void *data)
+static void static_list (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
@@ -81,7 +82,7 @@ GtkWidget *hbox;
 GtkWidget *button;
 
 hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_plane");
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   {
@@ -102,15 +103,12 @@ else
   }
 }
 
-static void static_apply (gamgi_plane *plane, gamgi_window *window)
+static void static_apply (gamgi_plane *plane, int scope, gamgi_window *window)
 {
 gamgi_atom *atom;
 gamgi_bond *bond;
 gamgi_object *parent;
 gamgi_dlist *dlist, *dlist_b;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *combo;
-int row;
 
 /*****************************************************
  * Remove plane data according to Scope combo box:   *
@@ -121,14 +119,11 @@ int row;
  * 4) Child: Remove the child list of a given class; *
  *****************************************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
 /******************************************
  * All: remove plane and all its contents *
  ******************************************/
 
-if (row == 0)
+if (scope == 0)
   {
   gamgi_engine_unlink_plane (plane);
   gamgi_engine_remove_plane (plane);
@@ -139,7 +134,7 @@ if (row == 0)
  * crystallographic planes and directions) and remove plane *
  ************************************************************/
 
-if (row == 1)
+if (scope == 1)
   {
   parent = plane->object.object;
   gamgi_engine_reparent_direction (plane->direction_start, parent);
@@ -155,7 +150,7 @@ if (row == 1)
  * planes are removed when defining atoms are removed  *
  *******************************************************/
 
-if (row == 2)
+if (scope == 2)
   {
   dlist = plane->direction_start;
   while (dlist != NULL)
@@ -192,7 +187,7 @@ if (row == 2)
  * Direction: remove direction list in plane *
  *********************************************/
 
-if (row == 3)
+if (scope == 3)
   {
   dlist = plane->direction_start;
   while (dlist != NULL)
@@ -207,7 +202,7 @@ if (row == 3)
  * are removed when defining atoms are removed    *
  **************************************************/
 
-if (row == 4)
+if (scope == 4)
   {
   dlist = plane->atom_start;
   while (dlist != NULL)
@@ -223,7 +218,7 @@ if (row == 4)
  * Bond: remove bond list in atom list in plane *
  ************************************************/
 
-if (row == 5)
+if (scope == 5)
   {
   dlist = plane->atom_start;
   while (dlist != NULL)
@@ -246,7 +241,7 @@ if (row == 5)
  * Orbital: remove orbital list in plane *
  *****************************************/
 
-if (row == 6)
+if (scope == 6)
   {
   dlist = plane->orbital_start;
   while (dlist != NULL)
@@ -260,7 +255,7 @@ if (row == 6)
  * Text: remove text list in plane *
  ***********************************/
 
-if (row == 7)
+if (scope == 7)
   {
   dlist = plane->text_start;
   while (dlist != NULL)
@@ -272,57 +267,129 @@ if (row == 7)
 
 }
 
+static void static_ok_global (int scope, gamgi_window *window)
+{
+gamgi_dlist *dlist, *planes;
+
+if (gamgi->planes == NULL)
+  { gamgi_gtk_dialog_message_create ("Error",
+  "Empty list of plane objects", window); return; }
+
+/************************************************
+ * for all windows: save layers as undo layers, *
+ * set current layer as new current object      *
+ ************************************************/
+
+gamgi_global_selection_undo ();
+gamgi_global_selection_focus ();
+
+/*********************************************************
+ * disable automatic mechanism to remove selection list, *
+ * so we can scan the list and remove it only in the end *
+ *********************************************************/
+
+planes = gamgi->planes;
+gamgi->planes = NULL;
+
+/****************************************************
+ * remove plane data as specified in scope combo box *
+ ****************************************************/
+
+for (dlist = planes; dlist != NULL; dlist = dlist->next)
+  static_apply (GAMGI_CAST_PLANE dlist->data, scope, window);
+
+/******************************************************
+ * remove the selection list of a class of objects    *
+ * only when objects of that class are really removed *
+ ******************************************************/
+
+gamgi->planes = planes;
+if (scope < 2)
+  gamgi_global_selection_remove (&gamgi->planes, "button_plane");
+
+/*****************************************
+ * For all windows: redraw gl_area image *
+ *****************************************/
+
+gamgi_global_selection_draw ();
+}
+
+static void static_ok_local (int scope, gamgi_window *window)
+{
+gamgi_plane *plane;
+GtkWidget *dialog = window->dialog0;
+
+/***************
+ * Pick object *
+ ***************/
+
+plane = GAMGI_CAST_PLANE gamgi_gtk_object_name_number (dialog,
+"entry_plane", GAMGI_ENGINE_PLANE, window);
+if (plane == NULL)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid plane object", window);
+  return;
+  }
+
+/*************************************************
+ * Before removing the plane, check if the       *
+ * current object is affected. In this case, the *
+ * current layer becomes the new current object. *
+ *************************************************/
+
+if (gamgi_engine_find_object (window->focus,
+GAMGI_CAST_OBJECT plane) == TRUE)
+  gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
+
+/***************************************
+ * Save current layer as undo buffer   *
+ * layer so it can be recovered later. *
+ ***************************************/
+
+gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
+
+/**************************************************
+ * remove plane data as chosen in scope combo box *
+ **************************************************/
+
+static_apply (plane, scope, window);
+
+/**********************************************
+ * Redraw gl_area image and reset plane entry *
+ **********************************************/
+
+gtk_widget_queue_draw (window->area);
+}
+
 static void static_ok (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
-gamgi_plane *plane;
 GtkWidget *dialog = window->dialog0;
 GtkWidget *button;
+GtkWidget *combo;
+int scope;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
-  {
-  /***************
-   * Pick method *
-   ***************/
+/*********************************************************
+ * get dialog data common to both local and global tasks *
+ *********************************************************/
 
-  plane = GAMGI_CAST_PLANE gamgi_gtk_object_name_number (dialog,
-  "entry_plane", GAMGI_ENGINE_PLANE, window);
-  if (plane == NULL)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid plane object", window);
-    return;
-    }
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
+scope = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
-  /*************************************************
-   * Before removing the plane, check if the       *
-   * current object is affected. In this case, the *
-   * current layer becomes the new current object. *
-   *************************************************/
+/********************************
+ * execute global or local task *
+ ********************************/
 
-  if (gamgi_engine_find_object (window->focus,
-  GAMGI_CAST_OBJECT plane) == TRUE)
-    gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  static_ok_global (scope, window);
+else
+  static_ok_local (scope, window);
 
-  /***************************************
-   * Save current layer as undo buffer   *
-   * layer so it can be recovered later. *
-   ***************************************/
+/***********************************************************
+ * clean dialog data common to both local and global tasks *
+ ***********************************************************/
 
-  gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
-
-  /**************************************************
-   * remove plane data as chosen in scope combo box *
-   **************************************************/
-
-  static_apply (plane, window);
-  }
-
-/*********************************************
- * Redraw gl_area image and reset text entry *
- *********************************************/
-
-gtk_widget_queue_draw (window->area);
 static_clean (window);
 }
 
@@ -369,7 +436,7 @@ GtkWidget *button;
  * local mouse selection only *
  ******************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE ||
 window_dialog != window_mouse) return;
 
@@ -447,15 +514,15 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 g_object_set_data (G_OBJECT (dialog), "entry_plane", entry);
 gtk_widget_show (entry);
 
-/**********
- * Global *
- **********/
+/********
+ * List *
+ ********/
 
-button = gtk_toggle_button_new_with_label ("Global");
+button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "toggled",
-G_CALLBACK (static_global), window);
-g_object_set_data (G_OBJECT (dialog), "button_global", button);
+G_CALLBACK (static_list), window);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /************
