@@ -144,7 +144,6 @@ GtkWidget *text_view;
 GtkTextBuffer *buffer;
 GtkTextIter start;
 GtkTextIter end;
-char token[GAMGI_ENGINE_TOKEN];
 char line[GAMGI_ENGINE_LINE];
 char *contents = NULL;
 const char *name;
@@ -168,7 +167,7 @@ if (gamgi_gtk_object_name (dialog, "entry_text",
 /*******************************************************************
  * text objects cannot be longer than GAMGI_ENGINE_LINE (200) char *
  *                                                                 *
- * get contents: buffer is free immediately and text->string is    *
+ * get contents and free it as soon as possible. text->string is   *
  * free inside gamgi_engine_remove_text (in case an error occurs)  *
  *******************************************************************/
 
@@ -184,10 +183,12 @@ GAMGI_ENGINE_LINE) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Text Contents", window);
   gamgi_engine_remove_text (text);
+  free (contents);
   return;
   }
 
 gamgi_mesa_text_create (text, contents);
+free (contents);
 
 /*************
  * get style *
@@ -215,16 +216,15 @@ if (text->style == GAMGI_MESA_SOLID) text->font += GAMGI_IO_FONTS_WIRED;
  * cancel everything when the font filename is not found    *
  ************************************************************/
 
-if (gamgi_mesa_text_font_increase (text) == FALSE)
+if (gamgi_mesa_text_center (text->font,
+text->string, text->length, text->center, line) == FALSE)
   {
-  gamgi_mesa_text_data_solid (text->font, token);
-  sprintf (line, "Unable to handle font file \"%s\"", token);
   gamgi_gtk_dialog_message_create ("Error", line, window);
-
   text->font = FALSE;
   gamgi_engine_remove_text (text);
   return;
   }
+gamgi_mesa_text_font_increase (text, NULL);
 
 /*************************
  * get x,y,z coordinates *
@@ -292,7 +292,7 @@ if (gamgi_io_token_double_scan (name, &euler[2], 0.0, 360.0) == FALSE)
   }
 
 /********************
- * get r,g,b colors *
+ * get R,G,B colors *
  ********************/
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_red");
@@ -336,7 +336,6 @@ GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
   return;
   }
 
-gamgi_mesa_text_center (text->font, text->string, text->length, text->center);
 gamgi_math_position_text_rotation_set (text, euler);
 gamgi_math_position_text_translation_set (text, origin);
 
