@@ -17,6 +17,7 @@
 #include "gamgi_io.h"
 #include "gamgi_global.h"
 
+#include "gamgi_engine_list.h"
 #include "gamgi_engine_find.h"
 #include "gamgi_gtk_dialog.h"
 #include "gamgi_gtk_history.h"
@@ -35,6 +36,20 @@
 #include "gamgi_math_position.h"
 #include "gamgi_io_token.h"
 #include "gamgi_io_error.h"
+#include "gamgi_global_selection.h"
+
+static struct {
+gamgi_bool new[14];
+
+char name[GAMGI_ENGINE_TOKEN];
+gamgi_enum style, font;
+gamgi_bool translation_absolute, rotation_absolute;
+double translation[3], rotation[3];
+
+char *contents;
+
+float red, green, blue;
+double scale; } cache;
 
 static gamgi_enum static_font (gamgi_enum style, int offset)
 {
@@ -315,482 +330,588 @@ gtk_entry_set_text (GTK_ENTRY (entry), "");
 
 /****************** internal function **************
  *                                                 *
- *                    STATIC_GLOBAL                *
- *                                                 *
- * Makes the text entry (but not the table button) *
- * sensitive when the local button is pressed and  *
- * insensitive when the global button is pressed.  *
+ *                     STATIC_LIST                 *
  *                                                 *
  ***************************************************/
 
-static void static_global (GtkWidget *widget, void *data)
+static void static_list (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *hbox, *button;
+GtkWidget *label, *button;
 
-hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_text");
-
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_text");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   {
-  /****************************
-   * Choose the Text directly *
-   ****************************/
+  /*********************************
+   * modify a single text directly *
+   *********************************/
 
-  gtk_widget_set_sensitive (hbox, TRUE);
+  gtk_label_set_text (GTK_LABEL (label), "Text");
   static_absolute (dialog);
   }
 else
   {
-  /********************************************
-   * Choose the Text List previously selected *
-   ********************************************/
+  /*********************************************
+   * modify multiple atoms previously selected *
+   *********************************************/
 
-  gtk_widget_set_sensitive (hbox, FALSE);
-  static_relative (dialog);
+  gtk_label_set_text (GTK_LABEL (label), "Name");
   static_reset (window);
+  static_relative (dialog);
   }
 }
 
-/****************** internal function ******************
- *                                                     *
- *                      STATIC_OK                      *
- *                                                     *
- * When the user clicks the Ok button, the parameters  *
- * in the dialog window are atributted to the text or  *
- * texts currently selected, overwriting the old ones. *
- *                                                     *
- *******************************************************/
-
-static void static_ok (GtkWidget *widget, void *data)
+static gamgi_bool static_grab (gamgi_window *window)
 {
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-gamgi_text *text;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *combo;
-GtkWidget *button;
 GtkWidget *entry;
+GtkWidget *button;
+GtkWidget *combo;
 GtkWidget *text_view;
 GtkTextBuffer *buffer;
 GtkTextIter start;
 GtkTextIter end;
-char token[GAMGI_ENGINE_TOKEN];
-char line[GAMGI_ENGINE_LINE];
-char *contents = NULL;
 const char *name;
-double euler[3], euler_old[3];
-double origin[3], origin_old[3];
-double center[3];
-double zero[3];
-double scale;
-float red, green, blue;
-gamgi_enum style, font;
-int row_style, row_font;
+int row, i = 0;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
+/*******************************************
+ * style, font: when style is unknown,     *
+ * the new font depends of the text object *
+ *******************************************/
+
+cache.new[++i] = FALSE;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row < 2) { cache.new[i] = TRUE; cache.style = row + 1; }
+
+cache.new[++i] = FALSE;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_font");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (cache.style == GAMGI_MESA_WIRED)
   {
-  /****************
-   * Local method *
-   ****************/
-
-  /**************************************
-   * Get name (possibly new) and number *
-   **************************************/
-
-  text = GAMGI_CAST_TEXT gamgi_gtk_object_number (dialog,
-  "entry_text", GAMGI_ENGINE_TEXT, window, token);
-  if (text == NULL)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Text Object", window);
-    return;
-    }
-
-  /**************************
-   * get initial parameters *
-   **************************/
-
-  style = text->style;
-  font = text->font;
-
-  red = text->red;
-  green = text->green;
-  blue = text->blue;
-  scale = text->object.scale;
-
-  /*********************************************
-   * grab data from style and font combo boxes *
-   *********************************************/
-
-  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
-  row_style = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
-  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_font");
-  row_font = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
-  /************************************************
-   * get new style and font: when style is Local, *
-   * the old text->style is preserved; when font  *
-   * is Local, the old text->font is preserved    *
-   ************************************************/
-
-  if (row_style == GAMGI_MESA_WIRED - 1)
-     {
-     style = GAMGI_MESA_WIRED;
-     if (row_font < GAMGI_IO_FONTS_WIRED) font = 1 + row_font;
-     }
-  else if (row_style == GAMGI_MESA_SOLID - 1)
-    {
-    style = GAMGI_MESA_SOLID;
-    if (row_font < GAMGI_IO_FONTS_SOLID) font = 1 + row_font + GAMGI_IO_FONTS_WIRED;
-    }
-  else if (row_font < GAMGI_IO_FONTS_TOTAL) { font = static_font (style, row_font); }
-
-  /******************************************
-   * check if style and font are compatible *
-   ******************************************/
-   
-  if (style == GAMGI_MESA_WIRED && font > GAMGI_IO_FONTS_WIRED)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Font Data", window);
-    return;
-    }
-
-  if (style == GAMGI_MESA_SOLID && font <= GAMGI_IO_FONTS_WIRED)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Font Data", window);
-    return;
-    }
-
-  /******************
-   * Get old origin *
-   ******************/
-
-  gamgi_math_position_text_translation_get (text, origin_old);
-
-  /******************
-   * Get new origin *
-   ******************/
-
-  button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_translation_absolute");
-  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
-    {
-    /****************************************************
-     * Absolute move: the default is the current origin *
-     ****************************************************/
-
-    gamgi_math_vector_copy (origin_old, origin);
-    }
-  else
-    {
-    /**************************************
-     * Relative move: the default is zero *
-     **************************************/
-
-    gamgi_math_vector_zero (origin);
-    }
-
-  /*****
-   * x *
-   *****/
-
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &origin[0], -DBL_MAX, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Position Data", window);
-    return;
-    }
-
-  /*****
-   * y *
-   *****/
-
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &origin[1], -DBL_MAX, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Position Data", window);
-    return;
-    }
-
-  /*****
-   * z *
-   *****/
-
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &origin[2], -DBL_MAX, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Position Data", window);
-    return;
-    }
-
-  /*****************
-   * Get old angle *
-   *****************/
-
-  gamgi_math_position_text_rotation_get (text, euler_old);
-
-  /*****************
-   * Get new angle *
-   *****************/
-
-  button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_rotation_absolute");
-  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
-    {
-    /****************************************************
-     * Absolute angle: the default is the current angle *
-     ****************************************************/
-
-    euler[0] = euler_old[0];
-    euler[1] = euler_old[1];
-    euler[2] = euler_old[2];
-    }
-  else
-    {
-    /**************************************
-     * Relative move: the default is zero *
-     **************************************/
-
-    euler[0] = 0.0;
-    euler[1] = 0.0;
-    euler[2] = 0.0;
-    }
-
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e1");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &euler[0], 0.0, 180.0) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Angle Data", window);
-    return;
-    }
-
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e2");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &euler[1], 0.0, 360.0) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Angle Data", window);
-    return;
-    }
-
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e3");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &euler[2], 0.0, 360.0) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Angle Data", window);
-    return;
-    }
-
-  /*************
-   * get color *
-   *************/
-
-  /*******
-   * red *
-   *******/
-
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_red");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_float_scan (name, &red, 0.0, 1.0) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Color Data", window);
-    return;
-    }
-
-  /*********
-   * green *
-   *********/
-
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_green");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_float_scan (name, &green, 0.0, 1.0) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Color Data", window);
-    return;
-    }
-
-  /********
-   * blue *
-   ********/
-
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_blue");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_float_scan (name, &blue, 0.0, 1.0) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Color Data", window);
-    return;
-    }
-
-  /*************
-   * Get scale *
-   *************/
-
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_double_scan (name,
-  &scale, GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Scale Data", window);
-    return;
-    }
-
-  /*********************
-   * get text contents *
-   *********************/
-
-  text_view = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "text_contents");
-  buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_view));
-  gtk_text_buffer_get_start_iter (buffer, &start);
-  gtk_text_buffer_get_end_iter (buffer, &end);
-
-  contents = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
-  if (gamgi_io_token_alpha_check (contents,
-  GAMGI_IO_FONT_ASCII, GAMGI_ENGINE_LINE) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Text Contents", window);
-    free (contents);
-    return;
-    }
-
-  if (gamgi_io_token_check (contents) == TRUE)
-    {
-    /********************
-     * new text message *
-     ********************/
-
-    if (gamgi_mesa_text_center (font,
-    contents, strlen (contents), center, line) == FALSE)
-      {
-      gamgi_gtk_dialog_message_create ("Error", line, window);
-      free (contents);
-      return;
-      }
-    }
-  else
-    {
-    /********************
-     * old text message *
-     ********************/
-
-    if (gamgi_mesa_text_center (font,
-    text->string, text->length, center, line) == FALSE)
-      {
-      gamgi_gtk_dialog_message_create ("Error", line, window);
-      free (contents);
-      return;
-      }
-    }
-
-  /********************************************************
-   * Data is ok: save current data and update to new data *
-   ********************************************************/
- 
-  /***************************************
-   * Save current layer as undo buffer   *
-   * layer so it can be recovered later. * 
-   ***************************************/
-
-  gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
-
-  /***************************************
-   * convert relative to absolute origin *
-   ***************************************/
-
-  button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_translation_relative");
-  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
-    gamgi_math_vector_add (origin, origin_old, origin);
-
-  /**************************************
-   * convert relative to absolute angle *
-   **************************************/
-
-  button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_rotation_relative");
-  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
-    gamgi_math_vector_add (euler, euler_old, euler);
-
-  /**************
-   * reset text *
-   **************/
-
-  gamgi_math_vector_zero (zero);
-  gamgi_math_position_text_rotation_set (text, zero);
-  gamgi_math_position_text_translation_set (text, zero);
-
-  /*****************************
-   * transfer new data to text *
-   *****************************/
-
-  text->style = style;
-  text->red = red;
-  text->green = green;
-  text->blue = blue;
-  text->object.scale = scale;
-
-  /***********************
-   * update glyph arrays *
-   ***********************/
-
-  if (gamgi_io_token_check (contents) == TRUE)
-    {
-    /*************************************
-     * update glyph arrays when contents *
-     * (and possibly) font changed       *
-     *************************************/
-
-    gamgi_mesa_text_font_decrease (text);
-    gamgi_mesa_text_remove (text);
-    gamgi_mesa_text_create (text, contents);
-    text->font = font;
-    gamgi_mesa_text_font_increase (text, NULL);
-    }
-  else if (font != text->font)
-    {
-    /*****************************************
-     * update glyph arrays when font changed *
-     *****************************************/
-
-    gamgi_mesa_text_font_decrease (text);
-    text->font = font;
-    gamgi_mesa_text_font_increase (text, NULL);
-    }
-
-  /***************
-   * free memory *
-   ***************/
-
-  free (contents);
-
-  /*********************************************
-   * Update the text name, which might be new. *
-   *********************************************/
-
-  strcpy (text->object.name, token);
-
-  gamgi_math_vector_copy (center, text->center);
-  gamgi_math_position_text_rotation_set (text, euler);
-  gamgi_math_position_text_translation_set (text, origin);
+  if (row < GAMGI_IO_FONTS_WIRED)
+    { cache.new[i] = TRUE; cache.font = 1 + row; }
+  }
+else if (cache.style == GAMGI_MESA_SOLID)
+  {
+  if (row < GAMGI_IO_FONTS_SOLID)
+    { cache.new[i] = TRUE; cache.font = 1 + row + GAMGI_IO_FONTS_WIRED; }
+  }
+else
+  {
+  if (row < GAMGI_IO_FONTS_TOTAL)
+    { cache.new[i] = TRUE; cache.font = row; }
   }
 
-/***********************************************************
- * Update statusbar, redraw gl_area image and reset dialog *
- ***********************************************************/
+/******************************
+ * translation: type, x, y, z *
+ ******************************/
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_translation_absolute");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  cache.translation_absolute = TRUE;
+else
+  cache.translation_absolute = FALSE;
+
+cache.new[++i] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[i] = TRUE;
+  if (gamgi_io_token_double_scan (name,
+  &cache.translation[0], -DBL_MAX, DBL_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid position", window);
+    return FALSE;
+    }
+  }
+
+cache.new[++i] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[i] = TRUE;
+  if (gamgi_io_token_double_scan (name,
+  &cache.translation[1], -DBL_MAX, DBL_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid position", window);
+    return FALSE;
+    }
+  }
+
+cache.new[++i] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[i] = TRUE;
+  if (gamgi_io_token_double_scan (name,
+  &cache.translation[2], -DBL_MAX, DBL_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid position", window);
+    return FALSE;
+    }
+  }
+
+/******************************
+ * rotation: type, e1, e2, e3 *
+ ******************************/
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_rotation_absolute");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  cache.rotation_absolute = TRUE;
+else
+  cache.rotation_absolute = FALSE;
+
+cache.new[++i] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e1");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[i] = TRUE;
+  if (gamgi_io_token_double_scan (name,
+  &cache.rotation[0], 0.0, 180.0) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid angle data", window);
+    return FALSE;
+    }
+  }
+
+cache.new[++i] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e2");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[i] = TRUE;
+  if (gamgi_io_token_double_scan (name,
+  &cache.rotation[1], 0.0, 360.0) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid angle data", window);
+    return FALSE;
+    }
+  }
+
+cache.new[++i] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e3");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[i] = TRUE;
+  if (gamgi_io_token_double_scan (name,
+  &cache.rotation[2], 0.0, 360.0) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid angle data", window);
+    return FALSE;
+    }
+  }
+
+/************
+ * contents *
+ ************/
+
+cache.new[++i] = FALSE;
+text_view = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "text_contents");
+buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_view));
+gtk_text_buffer_get_start_iter (buffer, &start);
+gtk_text_buffer_get_end_iter (buffer, &end);
+cache.contents = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
+if (gamgi_io_token_check (cache.contents) == TRUE)
+  {
+  cache.new[i] = TRUE;
+  if (gamgi_io_token_alpha_check (cache.contents,
+  GAMGI_IO_FONT_ASCII, GAMGI_ENGINE_LINE) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid text contents", window);
+    return FALSE;
+    }
+  }
+
+/***************************
+ * red, green, blue, scale *
+ ***************************/
+  
+cache.new[++i] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_red");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[i] = TRUE;
+  if (gamgi_io_token_float_scan (name,
+  &cache.red, 0.0, 1.0) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid color", window);
+    return FALSE;
+    }
+  }
+
+cache.new[++i] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_green");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[i] = TRUE;
+  if (gamgi_io_token_float_scan (name,
+  &cache.green, 0.0, 1.0) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid color", window);
+    return FALSE;
+    }
+  }
+
+cache.new[++i] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_blue");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[i] = TRUE;
+  if (gamgi_io_token_float_scan (name,
+  &cache.blue, 0.0, 1.0) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid color", window);
+    return FALSE;
+    }
+  }
+
+cache.new[++i] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[i] = TRUE;
+  if (gamgi_io_token_double_scan (name,
+  &cache.scale, GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid scale", window);
+    return FALSE;
+    }
+  }
+
+return TRUE;
+}
+
+static gamgi_bool static_apply (gamgi_text *text, gamgi_bool local,
+gamgi_window *window)
+{
+char name[GAMGI_ENGINE_TOKEN];
+char line[GAMGI_ENGINE_LINE];
+double origin[3], origin_old[3];
+double euler[3], euler_old[3];
+double zero[3], center[3];
+double scale;
+gamgi_enum style, font;
+float red, green, blue;
+int i = 0;
+
+/*************************
+ * import data from text *
+ *************************/
+
+strcpy (name, text->object.name);
+style = text->style;
+font = text->font;
+
+gamgi_math_position_text_translation_get (text, origin_old);
+if (cache.translation_absolute == TRUE)
+  gamgi_math_vector_copy (origin_old, origin);
+else
+  gamgi_math_vector_zero (origin);
+
+gamgi_math_position_text_rotation_get (text, euler_old);
+if (cache.rotation_absolute == TRUE)
+  gamgi_math_vector_copy (euler_old, euler);
+else
+  gamgi_math_vector_zero (euler);
+
+red = text->red;
+green = text->green;
+blue = text->blue;
+scale = text->object.scale;
+
+/******************
+ * apply new data *
+ ******************/
+
+if (cache.new[i++] == TRUE)
+  strcpy (name, cache.name);
+
+/******************************************************************
+ * when style is unknown, the new font depends of the text object *
+ ******************************************************************/
+
+if (cache.new[1] == FALSE && cache.new[2] == TRUE)
+  { cache.font = static_font (text->style, cache.font); }
+
+if (cache.new[i++] == TRUE) style = cache.style;
+if (cache.new[i++] == TRUE) font = cache.font;
+
+if (style == GAMGI_MESA_WIRED && font > GAMGI_IO_FONTS_WIRED)
+  {
+  if (local == TRUE)
+    gamgi_gtk_dialog_message_create ("Error", "Invalid font data", window);
+  return TRUE;
+  }
+if (style == GAMGI_MESA_SOLID && font <= GAMGI_IO_FONTS_WIRED)
+  {
+  if (local == TRUE)
+    gamgi_gtk_dialog_message_create ("Error", "Invalid font data", window);
+  return TRUE;
+  }
+
+if (cache.new[i++] == TRUE)
+  origin[0] = cache.translation[0];
+if (cache.new[i++] == TRUE)
+  origin[1] = cache.translation[1];
+if (cache.new[i++] == TRUE)
+  origin[2] = cache.translation[2];
+
+if (cache.new[i++] == TRUE)
+  euler[0] = cache.rotation[0];
+if (cache.new[i++] == TRUE)
+  euler[1] = cache.rotation[1];
+if (cache.new[i++] == TRUE)
+  euler[2] = cache.rotation[2];
+
+/******************
+ * get new center *
+ ******************/
+
+if (cache.new[i++] == TRUE)
+  {
+  if (gamgi_mesa_text_center (font,
+  cache.contents, strlen (cache.contents), center, line) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", line, window);
+    return FALSE;
+    }
+  }
+else
+  {
+  if (gamgi_mesa_text_center (font,
+  text->string, text->length, center, line) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", line, window);
+    return FALSE;
+    }
+  }
+
+if (cache.new[i++] == TRUE)
+  red = cache.red;
+if (cache.new[i++] == TRUE)
+  green = cache.green;
+if (cache.new[i++] == TRUE)
+  blue = cache.blue;
+if (cache.new[i++] == TRUE)
+  scale = cache.scale;
+
+/***************************************
+ * Save current layer as undo buffer   *
+ * layer so it can be recovered later. *
+ ***************************************/
+
+if (local == TRUE)
+  gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
+
+/***********************************************
+ * export data to text: reset position; update *
+ * glyph arrays when contents or font changed  *
+ ***********************************************/
+ 
+strcpy (text->object.name, name);
+text->style = style;
+
+gamgi_math_vector_zero (zero);
+gamgi_math_position_text_rotation_set (text, zero);
+gamgi_math_position_text_translation_set (text, zero);
+
+if (cache.new[9] == TRUE)
+  {
+  gamgi_mesa_text_font_decrease (text);
+  gamgi_mesa_text_remove (text);
+  gamgi_mesa_text_create (text, cache.contents);
+  text->font = font;
+  gamgi_mesa_text_font_increase (text, NULL);
+  }
+else if (font != text->font)
+  {
+  gamgi_mesa_text_font_decrease (text);
+  text->font = font;
+  gamgi_mesa_text_font_increase (text, NULL);
+  }
+gamgi_math_vector_copy (center, text->center);
+
+if (cache.rotation_absolute == FALSE)
+  gamgi_math_vector_add (euler, euler_old, euler);
+gamgi_math_position_text_rotation_set (text, euler);
+
+if (cache.translation_absolute == FALSE)
+  gamgi_math_vector_add (origin, origin_old, origin);
+gamgi_math_position_text_translation_set (text, origin);
+
+text->red = red;
+text->green = green;
+text->blue = blue;
+text->object.scale = scale;
+
+return TRUE;
+}
+
+static void static_ok_global (gamgi_window *window)
+{
+gamgi_object *object;
+gamgi_dlist *dlist;
+gamgi_slist *slist, *start;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+const char *name;
+char line[GAMGI_ENGINE_LINE];
+char string[GAMGI_ENGINE_STRING];
+
+if (gamgi->texts == NULL)
+  { gamgi_gtk_dialog_message_create ("Error",
+  "Empty list of text objects", window); return; }
+
+/****************************
+ * Pick name (possibly new) *
+ ****************************/
+
+cache.new[0] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_text");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[0] = TRUE;
+  if (gamgi_io_token_alpha_scan (name,
+  cache.name, GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid text identity", window);
+    return;
+    }
+  }
+
+if (static_grab (window) == FALSE) return;
+
+/************************************************
+ * for all windows: save layers as undo layers, *
+ * set current layer as new current object      *
+ ************************************************/
+
+gamgi_global_selection_undo ();
+gamgi_global_selection_focus ();
+
+/*******************************************
+ * modify text data as specified in dialog *
+ *******************************************/
+
+start = NULL;
+for (dlist = gamgi->texts; dlist != NULL; dlist = dlist->next)
+  if (static_apply (GAMGI_CAST_TEXT dlist->data, FALSE, window) == FALSE)
+    {
+    start = gamgi_engine_slist_add_start (start);
+    start->data = dlist->data;
+    }
+
+if (start != NULL)
+  {
+  printf ("error\n");
+  fflush (stdout);
+
+  sprintf (line, "The following objects could not be modified:\n");
+
+  start = gamgi_engine_slist_invert (start);
+  for (slist = start; slist != NULL; slist = slist->next)
+    {
+    if (slist != start) strcat (line, ", ");
+
+    if (strlen (line) > GAMGI_ENGINE_LINE - GAMGI_ENGINE_STRING)
+      { strcat (line, "..."); break; }
+
+    object = GAMGI_CAST_OBJECT slist->data;
+    sprintf (string, "%s %d", object->name, object->number);
+    strcat (line, string);
+    }
+  gamgi_gtk_dialog_message_create ("Error", line, window);
+  gamgi_engine_slist_remove_all (start);
+  }
+
+/*****************************************
+ * For all windows: redraw gl_area image *
+ *****************************************/
+
+gamgi_global_selection_draw ();
+
+/****************
+ * reset dialog *
+ ****************/
 
-gamgi_gtk_statusbar_focus_modify (window);
-gtk_widget_queue_draw (window->area);
 static_reset (window);
 }
 
+static void static_ok_local (gamgi_window *window)
+{
+gamgi_text *text;
+GtkWidget *dialog = window->dialog0;
+
+/*******************************************
+ * Pick object and get name (possibly new) *
+ *******************************************/
+
+cache.new[0] = TRUE;
+text = GAMGI_CAST_TEXT gamgi_gtk_object_number (dialog,
+"entry_text", GAMGI_ENGINE_TEXT, window, cache.name);
+if (text == NULL)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid text identity", window);
+  return;
+  }
+
+if (static_grab (window) == FALSE) return;
+
+/*******************************************
+ * modify text data as specified in dialog *
+ *******************************************/
+
+if (static_apply (text, TRUE, window) == FALSE) return;
+
+/*********************************************
+ * Redraw gl_area image and reset atom entry *
+ *********************************************/
+
+gtk_widget_queue_draw (window->area);
+
+/****************
+ * reset dialog *
+ ****************/
+
+static_reset (window);
+}
+
+static void static_ok (GtkWidget *widget, void *data)
+{
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *dialog = window->dialog0;
+GtkWidget* button;
+
+/*********************************************
+ * modify data: execute global or local task *
+ *********************************************/
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  static_ok_global (window);
+else
+  static_ok_local (window);
+
+/***************
+ * free memory *
+ ***************/
+
+free (cache.contents);
+}
+
 static void static_init (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
@@ -942,7 +1063,7 @@ GtkWidget *button;
  * local mouse selection only *
  ******************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE ||
 window_dialog != window_mouse) return;
 
@@ -1011,11 +1132,11 @@ gtk_widget_show (hbox_left);
 
 hbox_left_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "hbox_text", hbox_left_left);
 gtk_widget_show (hbox_left_left);
 
 label = gtk_label_new ("Text");
 gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "label_text", label);
 gtk_widget_show (label);
 
 entry = gtk_entry_new ();
@@ -1025,15 +1146,15 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 g_object_set_data (G_OBJECT (dialog), "entry_text", entry);
 gtk_widget_show (entry);
 
-/**********
- * Global *
- **********/
+/********
+ * List *
+ ********/
 
-button = gtk_toggle_button_new_with_label ("Global");
+button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "toggled",
-G_CALLBACK (static_global), window);
-g_object_set_data (G_OBJECT (dialog), "button_global", button);
+G_CALLBACK (static_list), window);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /************
