@@ -145,15 +145,19 @@ int *x, int *y, gamgi_bool *push, void *data)
 {
 GtkRequisition size;
 GtkWidget *button  = (GtkWidget *) data;
+GtkAllocation allocation;
+GdkWindow *drawable;
 
 /********************************
  * set position for pop up menu *
  ********************************/
 
 gtk_widget_size_request (button, &size);
-gdk_window_get_origin (button->window, x, y);
-*x += button->allocation.x;
-*y += button->allocation.y + size.height / 2 ;
+drawable = gtk_widget_get_window (button);
+gdk_window_get_origin (drawable, x, y);
+gtk_widget_get_allocation (button, &allocation);
+*x += allocation.x;
+*y += allocation.y + size.height / 2 ;
 
 /****************************
  * set size for pop up menu *
@@ -627,6 +631,7 @@ GtkWidget *hbox;
 GtkWidget *event_box;
 GtkWidget *item;
 GtkAccelGroup *group;
+GdkWindow *drawable;
 char string[2 * GAMGI_ENGINE_TOKEN];
 
 /**************** 
@@ -1343,7 +1348,8 @@ gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT layer, window);
  
 gtk_widget_show (window->window);
 
-gdk_window_raise (window->window->window);
+drawable = gtk_widget_get_window (window->window);
+gdk_window_raise (drawable);
 
 if (window->top_flag == FALSE) gtk_widget_hide (window->top);
 if (window->medium_flag == FALSE) gtk_widget_hide (window->medium);
