@@ -15,7 +15,7 @@
 
 static gamgi_enum static_class (gamgi_window *window);
 
-static void static_link (GtkWidget *widget, void *data);
+static void static_method (GtkWidget *widget, void *data);
 
 static void static_reset (gamgi_window *window);
 
@@ -40,7 +40,7 @@ static void static_press (gamgi_object *object, void *data);
  **********************/
 
 void gamgi_gtk_window_link_press (gamgi_window *window_mouse,
-int x, int y, gamgi_window *window_dialog);
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog);
 
 void gamgi_gtk_window_link (GtkWidget *widget, void *data);
 
