@@ -26,6 +26,7 @@
 #include "gamgi_gtk_gamgi_exit.h"
 #include "gamgi_mesa_select.h"
 #include "gamgi_io_token.h"
+#include "gamgi_global_selection.h"
 
 static void static_clean (gamgi_window *window)
 {
@@ -67,15 +68,15 @@ combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 }
 
-/*********************** internal function ****************
- *                                                        *
- *                         STATIC_GLOBAL                  *
- *                                                        *
- * When the global button is on, disable the window entry *
- * and reset dialog, otherwise, enable the window entry.  *        
- **********************************************************/
+/*********************** internal function ***************
+ *                                                       *
+ *                         STATIC_LIST                   *
+ *                                                       *
+ * When the List button is on, disable the window entry  *
+ * and reset dialog, otherwise, enable the window entry. *
+ *********************************************************/
 
-static void static_global (GtkWidget *widget, void *data)
+static void static_list (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
@@ -83,7 +84,7 @@ GtkWidget *hbox;
 GtkWidget *button;
 
 hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_window");
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   {
@@ -105,12 +106,9 @@ else
 }
 
 static void static_apply (gamgi_window *window_mouse, 
-gamgi_window *window_dialog)
+int scope, gamgi_window *window_dialog)
 {
 gamgi_dlist *dlist;
-GtkWidget *dialog = window_dialog->dialog0;
-GtkWidget *combo;
-int row;
 
 /******************************************************
  * window_mouse is the selected window, window_dialog *
@@ -123,14 +121,11 @@ int row;
  * 2) Contents: remove all child objects in window; *
  ****************************************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
 /*******************************************
  * All: remove window and all its contents *
  *******************************************/
 
-if (row == 0)
+if (scope == 0)
   {
   if (gamgi->window_start == gamgi->window_end)
     gamgi_gtk_gamgi_exit_ok (NULL, window_mouse);
@@ -142,7 +137,7 @@ if (row == 0)
  * Contents: remove all child objects in window *
  ************************************************/
 
-if (row == 1)
+if (scope == 1)
   {
   dlist = window_mouse->layer_start;
   while (dlist != NULL)
@@ -157,41 +152,103 @@ if (row == 1)
 
 }
 
-static void static_ok (GtkWidget *widget, void *data)
+static void static_ok_global (int scope, gamgi_window *window_dialog)
+{
+gamgi_dlist *dlist, *windows;
+
+if (gamgi->windows == NULL)
+  { gamgi_gtk_dialog_message_create ("Error",
+  "Empty list of window objects", window_dialog); return; }
+
+/*********************************************************
+ * disable automatic mechanism to remove selection list, *
+ * so we can scan the list and remove it only in the end *
+ *********************************************************/
+
+windows = gamgi->windows;
+gamgi->windows = NULL;
+
+/******************************************************
+ * remove window data as specified in scope combo box *
+ ******************************************************/
+
+for (dlist = windows; dlist != NULL; dlist = dlist->next)
+  static_apply (GAMGI_CAST_WINDOW dlist->data, scope, window_dialog);
+
+/*****************************************************************
+ *       remove the selection list of a class of objects         *
+ *       only when objects of that class are really removed      *
+ *                                                               *
+ * remove list and change button color for remaining windows     *
+ * (when all windows are removed, all gtk widgets have already   *
+ * been removed at this stage, but the last window still exists) *
+ *****************************************************************/
+
+gamgi->windows = windows;
+if (scope < 1)
+  {
+  gamgi_engine_dlist_remove_all (gamgi->windows);
+  gamgi->windows = NULL;
+
+  if (gamgi->window_start->window != NULL)
+    gamgi_global_selection_hide ("button_window");
+  }
+}
+
+static void static_ok_local (int scope, gamgi_window *window_dialog)
 {
-gamgi_window *window_dialog = GAMGI_CAST_WINDOW data;
 gamgi_window *window_mouse;
 GtkWidget *dialog = window_dialog->dialog0;
-GtkWidget *button;
 
 /***************************************************************
  * window_mouse is the window where the user presses the mouse *
  * window_dialog is the window where the dialog window is open *
  ***************************************************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
+/***************
+ * Pick method *
+ ***************/
+
+window_mouse = GAMGI_CAST_WINDOW gamgi_gtk_object_name_number (dialog,
+"entry_window", GAMGI_ENGINE_WINDOW, window_dialog);
+if (window_mouse == NULL)
   {
-  /***************
-   * Pick method *
-   ***************/
-
-  window_mouse = GAMGI_CAST_WINDOW gamgi_gtk_object_name_number (dialog,
-  "entry_window", GAMGI_ENGINE_WINDOW, window_dialog);
-  if (window_mouse == NULL)
-    {
-    gamgi_gtk_dialog_message_create ("Error", 
-    "Invalid window object", window_dialog);
-    return;
-    }
-
-  /***************************************************
-   * remove window data as chosen in scope combo box *
-   ***************************************************/
-
-  static_apply (window_mouse, window_dialog);
+  gamgi_gtk_dialog_message_create ("Error", 
+  "Invalid window object", window_dialog);
+  return;
   }
 
+/***************************************************
+ * remove window data as chosen in scope combo box *
+ ***************************************************/
+
+static_apply (window_mouse, scope, window_dialog);
+}
+
+static void static_ok (GtkWidget *widget, void *data)
+{
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *button;
+GtkWidget *combo;
+int scope;
+
+/*********************************************************
+ * get dialog data common to both local and global tasks *
+ *********************************************************/
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
+scope = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+
+/********************************
+ * execute global or local task *
+ ********************************/
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  static_ok_global (scope, window);
+else
+  static_ok_local (scope, window);
 }
 
 static void static_init (gamgi_window *window)
@@ -318,7 +375,7 @@ GtkWidget *button;
  * local mouse selection only *
  ******************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE ||
 window_dialog != window_mouse) return;
 
@@ -396,15 +453,15 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 g_object_set_data (G_OBJECT (dialog), "entry_window", entry);
 gtk_widget_show (entry);
 
-/**********
- * Global *
- **********/
+/********
+ * List *
+ ********/
 
-button = gtk_toggle_button_new_with_label ("Global");
+button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "toggled",
-G_CALLBACK (static_global), window);
-g_object_set_data (G_OBJECT (dialog), "button_global", button);
+G_CALLBACK (static_list), window);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /************
