@@ -17,11 +17,15 @@ static void static_clean (gamgi_window *window);
 
 static void static_reset (gamgi_window *window);
 
-static void static_global (GtkWidget *widget, void *data);
+static void static_list (GtkWidget *widget, void *data);
 
-static void static_apply (gamgi_window *window_mouse,
+static void static_apply (gamgi_window *window_mouse, int scope,
 gamgi_window *window_dialog);
 
+static void static_ok_global (int scope, gamgi_window *window_dialog);
+
+static void static_ok_local (int scope, gamgi_window *window_dialog);
+
 static void static_ok (GtkWidget *widget, void *data);
 
 static void static_init (gamgi_window *window);
