@@ -888,6 +888,7 @@ return TRUE;
 gamgi_bool gamgi_io_file_write (char *fullname, gamgi_window *window)
 {
 gamgi_bool error = FALSE;
+GtkAllocation allocation;
 FILE *fp;
 char *shortname;
 char *extension;
@@ -921,8 +922,9 @@ extension = gamgi_io_file_extension (fullname);
  * nonexistent or unrecognized export a GAMGI xml file *
  *******************************************************/
 
-width = window->area->allocation.width;
-height = window->area->allocation.height;
+gtk_widget_get_allocation (window->area, &allocation);
+width = allocation.width;
+height = allocation.height;
 
 if (extension == NULL)
   gamgi_expat_export_gml (fp, window, &error);
