@@ -222,7 +222,7 @@ gamgi_bool lights, gamgi_bool *error)
 gamgi_dlist *dlist;
 char string[GAMGI_ENGINE_LINE];
 double endpoint[3];
-double medium[3], sub[3], axis[3];
+double center[3], sub[3], axis[3];
 double length, radius;
 double angle = 0.0;
 float background[4];
@@ -237,7 +237,7 @@ if (bond->atom2 == NULL) return;
  * function is executed only for atom1 *
  ***************************************/
 
-if (bond->color==TRUE && bond->atom2==atom) return;
+if (bond->color == TRUE && bond->atom2 == atom) return;
 
 if (bond->color == FALSE)
   {
@@ -277,9 +277,9 @@ if (bond->draw == gamgi_mesa_bond_draw_cylinder)
 
   radius = bond->object.scale * bond->size * gamgi->atom->min;
 
-  medium[0] = (atom->position[0] + endpoint[0]) / 2.0;
-  medium[1] = (atom->position[1] + endpoint[1]) / 2.0;
-  medium[2] = (atom->position[2] + endpoint[2]) / 2.0;
+  center[0] = (atom->position[0] + endpoint[0]) / 2.0;
+  center[1] = (atom->position[1] + endpoint[1]) / 2.0;
+  center[2] = (atom->position[2] + endpoint[2]) / 2.0;
 
   if (atom == bond->atom1)
     gamgi_math_vector_sub (atom->position, endpoint, sub);
@@ -291,9 +291,9 @@ if (bond->draw == gamgi_mesa_bond_draw_cylinder)
   gamgi_math_vector_normal (axis);
 		
   sprintf (string, "<Transform translation=\"%.*f %.*f %.*f\" rotation=\"%.*f %.*f %.*f %.*f\">\n", 
-  gamgi->gamgi->length, medium[0], 
-  gamgi->gamgi->length, medium[1], 
-  gamgi->gamgi->length, medium[2],
+  gamgi->gamgi->length, center[0], 
+  gamgi->gamgi->length, center[1], 
+  gamgi->gamgi->length, center[2],
   gamgi->gamgi->length, axis[0], 
   gamgi->gamgi->length, axis[1], 
   gamgi->gamgi->length, axis[2], 
@@ -406,16 +406,31 @@ else
     }
   }
 
+/**************************************************
+ * when color is inherited from the parent atoms, *
+ * this function is run for each atom, but the    *
+ * section below is executed only for atom 1      *
+ **************************************************/
+
+if (bond->color == FALSE && atom == bond->atom2) return;
+
 /********************************
  * child objects: orbital, text *
  ********************************/
 
-/* correct */
+center[0] = (bond->atom1->position[0] + bond->atom2->position[0]) / 2.0;
+center[1] = (bond->atom1->position[1] + bond->atom2->position[1]) / 2.0;
+center[2] = (bond->atom1->position[2] + bond->atom2->position[2]) / 2.0;
+
+static_scale (fp, bond->object.scale, center, error);
+
 for (dlist = bond->orbital_start; dlist != NULL; dlist = dlist->next)
   static_orbital (fp, GAMGI_CAST_ORBITAL dlist->data, lights, error);
 	
 for (dlist = bond->text_start; dlist != NULL; dlist = dlist->next)
   static_text (fp, GAMGI_CAST_TEXT dlist->data, lights, error);
+
+static_unscale (fp, bond->object.scale, error);
 }
 
 static void static_atom (FILE *fp, gamgi_atom *atom, 
@@ -486,7 +501,7 @@ if (atom->draw == gamgi_mesa_atom_draw_sphere || atom->bond_start == NULL)
 /**************************************
  * child objects: bond, orbital, text *
  **************************************/
-	
+
 for (dlist = atom->bond_start; dlist != NULL; dlist = dlist->next)
   static_bond (fp, GAMGI_CAST_BOND dlist->data, atom, lights, error);
 
@@ -740,11 +755,80 @@ if (plane->autonomy != GAMGI_GTK_NONE && plane->loops[0] != 0)
 static void static_group (FILE *fp, gamgi_group *group, 
 gamgi_bool lights, gamgi_bool *error)
 {
-gamgi_dlist *dlist;
-double center[3];
+gamgi_dlist * dlist;
+char string[GAMGI_ENGINE_LINE];
+double axis[4];
+double phi;
+float background[4];
 
-gamgi_math_vector_zero (center);
-static_scale (fp, group->object.scale, center, error);
+glGetFloatv (GL_COLOR_CLEAR_VALUE, background);
+
+static_scale (fp, group->object.scale, group->center, error);
+
+gamgi_math_quaternion_to_axis (group->quaternion, &phi, axis);
+
+if (group->loops != NULL)
+  {
+  sprintf (string, 
+  "<Transform translation=\"%.*f %.*f %.*f\" rotation=\"%.*f %.*f %.*f %.*f\">\n",
+  gamgi->gamgi->length, group->origin[0],
+  gamgi->gamgi->length, group->origin[1],
+  gamgi->gamgi->length, group->origin[2],
+  gamgi->gamgi->length, axis[0],
+  gamgi->gamgi->length, axis[1],
+  gamgi->gamgi->length, axis[2],
+  gamgi->gamgi->angle, phi);
+  gamgi_io_file_fprintf (fp, string, error);
+
+  gamgi_io_file_fprintf (fp, "<Shape>\n<Appearance>\n", error);
+  sprintf (string, "<LineProperties linewidthScaleFactor=\"%.*f\"/>",
+  GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_POLYHEDRON_WIDTH);
+  gamgi_io_file_fprintf (fp, string, error);
+
+  if (group->faces == FALSE)
+    sprintf (string, "<Material emissiveColor=\"%.*f %.*f %.*f\"/>\n",
+    GAMGI_MATH_DECIMAL_COLOR, group->red,
+    GAMGI_MATH_DECIMAL_COLOR, group->green,
+    GAMGI_MATH_DECIMAL_COLOR, group->blue);
+  else if (lights == TRUE)
+    sprintf (string, "<Material diffuseColor=\"%.*f %.*f %.*f\"/>\n",
+    GAMGI_MATH_DECIMAL_COLOR, background[0],
+    GAMGI_MATH_DECIMAL_COLOR, background[1],
+    GAMGI_MATH_DECIMAL_COLOR, background[2]);
+  else
+    sprintf (string, "<Material emissiveColor=\"%.*f %.*f %.*f\"/>\n",
+    GAMGI_MATH_DECIMAL_COLOR, background[0],
+    GAMGI_MATH_DECIMAL_COLOR, background[1],
+    GAMGI_MATH_DECIMAL_COLOR, background[2]);
+  gamgi_io_file_fprintf (fp, string, error);
+  gamgi_io_file_fprintf (fp, "</Appearance>\n", error);
+
+  gamgi_io_x3d_render_loops (fp, group->loops, group->points, error);
+
+  if (group->faces == TRUE)
+    {
+    gamgi_io_file_fprintf (fp, "</Shape>\n<Shape>\n", error);
+
+    gamgi_io_file_fprintf (fp, "<Appearance>\n", error);
+    if (lights == TRUE)
+      sprintf (string, "<Material diffuseColor=\"%.*f %.*f %.*f\"/>\n",
+      GAMGI_MATH_DECIMAL_COLOR, group->red,
+      GAMGI_MATH_DECIMAL_COLOR, group->green,
+      GAMGI_MATH_DECIMAL_COLOR, group->blue);
+    else
+      sprintf (string, "<Material emissiveColor=\"%.*f %.*f %.*f\"/>\n",
+      GAMGI_MATH_DECIMAL_COLOR, group->red,
+      GAMGI_MATH_DECIMAL_COLOR, group->green,
+      GAMGI_MATH_DECIMAL_COLOR, group->blue);
+    gamgi_io_file_fprintf (fp, string, error);
+    gamgi_io_file_fprintf (fp, "</Appearance>\n", error);
+
+    gamgi_io_x3d_render_polygons (fp, group->loops, group->points, error);
+    }
+
+  gamgi_io_file_fprintf (fp, "</Shape>\n", error);
+  gamgi_io_file_fprintf(fp, "</Transform>\n", error);
+  }
 
 /**********************************
  * child objects: group, plane,   *
@@ -824,7 +908,8 @@ gamgi_math_quaternion_to_axis (cluster->quaternion, &phi, axis);
 
 if (cluster->loops != NULL)
   {
-  sprintf (string, "<Transform translation=\"%.*f %.*f %.*f\" rotation=\"%.*f %.*f %.*f %.*f\">\n",
+  sprintf (string, 
+  "<Transform translation=\"%.*f %.*f %.*f\" rotation=\"%.*f %.*f %.*f %.*f\">\n",
   gamgi->gamgi->length, cluster->origin[0], 
   gamgi->gamgi->length, cluster->origin[1], 
   gamgi->gamgi->length, cluster->origin[2],
@@ -836,9 +921,9 @@ if (cluster->loops != NULL)
 
   gamgi_io_file_fprintf (fp, "<Shape>\n<Appearance>\n", error);
   sprintf (string, "<LineProperties linewidthScaleFactor=\"%.*f\"/>", 
-  GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_CLUSTER_WIDTH);
+  GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_POLYHEDRON_WIDTH);
   gamgi_io_file_fprintf (fp, string, error);
-		
+
   if (cluster->faces == FALSE)
     sprintf (string, "<Material emissiveColor=\"%.*f %.*f %.*f\"/>\n", 
     GAMGI_MATH_DECIMAL_COLOR, cluster->colors[0],
@@ -865,13 +950,13 @@ if (cluster->loops != NULL)
     gamgi_io_x3d_render_polygons_color (fp, cluster->loops, 
     cluster->points, cluster->paints, cluster->colors, error);
     }
-		
+
   gamgi_io_file_fprintf (fp, "</Shape>\n", error);
 
-  /* CHECK: perhaps this should be before closing shape? */
-  if (cluster->seeds == TRUE)
-    gamgi_io_x3d_render_points (fp, cluster->n_seeds, 
+  if (cluster->dots == TRUE)
+    gamgi_io_x3d_render_points (fp, cluster->n_dots, 
     cluster->points, cluster->colors, error);
+
   gamgi_io_file_fprintf(fp, "</Transform>\n", error);
   }
 
