@@ -1677,11 +1677,15 @@ int gamgi_mesa_grab_layer (gamgi_layer *layer, gamgi_window *window,
 int class, int level, int offset, gamgi_object **objects, int *levels)
 {
 gamgi_dlist *dlist;
-float width = window->area->allocation.width;
-float height = window->area->allocation.height;
-float aspect = width/height;
+GtkAllocation allocation;
+float width, height, aspect;
 float top = layer->top;
 
+gtk_widget_get_allocation (window->area, &allocation);
+width = allocation.width;
+height = allocation.height;
+aspect = width / height;
+
 /***************************************************
  * reset depth buffer, reset Projection parameters *
  ***************************************************/
