@@ -1149,11 +1149,15 @@ gamgi_object **gamgi_mesa_pick_layer (gamgi_layer *layer,
 gamgi_window *window, int class, gamgi_object **array) 
 {
 gamgi_dlist *dlist;
-float width = window->area->allocation.width;
-float height = window->area->allocation.height;
-float aspect = width/height;
+GtkAllocation allocation;
+float width, height, aspect;
 float top = layer->top;
 
+gtk_widget_get_allocation (window->area, &allocation);
+width = allocation.width;
+height = allocation.height;
+aspect = width / height;
+
 /************************************************
  * reset depth buffer and projection parameters *
  ************************************************/
