@@ -97,11 +97,13 @@
 static void static_select (gamgi_object *object, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
+GdkWindow *drawable;
 
 if (object->class == GAMGI_ENGINE_WINDOW)
   {
   window = GAMGI_CAST_WINDOW object;
-  gdk_window_raise (window->window->window);
+  drawable = gtk_widget_get_window (window->window);
+  gdk_window_raise (drawable);
   }
 
 if (object->class == GAMGI_ENGINE_LAYER)
@@ -1040,10 +1042,10 @@ else
 
 void gamgi_mesa_select_draw (gamgi_window *window)
 {
+GtkAllocation allocation;
 float *color = window->layer->color;
 int *box = gamgi->box;
-int width = window->area->allocation.width;
-int height = window->area->allocation.height;
+int width, height;
 int square = GAMGI_MESA_SELECT_SQUARE;
 
 if (window != gamgi->window_mouse) return;
@@ -1054,6 +1056,10 @@ if (window != gamgi->window_mouse) return;
 
 if (gamgi->state < GAMGI_MESA_SELECT_SIZE) return;
 
+gtk_widget_get_allocation (window->area, &allocation);
+width = allocation.width;
+height = allocation.height;
+
 /**************************************************
  * equivalent to gluOrtho2D (0, width, 0, height) *
  **************************************************/
@@ -1245,11 +1251,15 @@ gtk_widget_queue_draw (window->area);
 
 void gamgi_mesa_select_notify (int x, int y, gamgi_window *window)
 {
+GtkAllocation allocation;
 int *box = gamgi->box;
-int height = window->area->allocation.height;
+int height;
 int square = GAMGI_MESA_SELECT_SQUARE;
 int dx, dy;
 
+gtk_widget_get_allocation (window->area, &allocation);
+height = allocation.height;
+
 if (gamgi->state == GAMGI_MESA_SELECT_SIZE)
   {
   box[2] = x;
