@@ -494,6 +494,7 @@ while (dlist != NULL)
 
 void gamgi_mesa_translate_object (gamgi_object *object, double *translate)
 {
+gamgi_group *group;
 gamgi_plane *plane;
 gamgi_direction *direction;
 
@@ -533,7 +534,11 @@ switch (object->class)
   break;
 
   case GAMGI_ENGINE_GROUP:
-  gamgi_mesa_translate_group (GAMGI_CAST_GROUP object, translate);
+  group = GAMGI_CAST_GROUP object;
+  if (group->autonomy == GAMGI_GTK_NONE)
+    gamgi_mesa_translate_object (object->object, translate);
+  else
+    gamgi_mesa_translate_group (group, translate);
   break;
 
   case GAMGI_ENGINE_MOLECULE:
