@@ -29,46 +29,6 @@
 #include "gamgi_phys_cell.h"
 #include "gamgi_phys_space.h"
 
-static void static_range_one (double *u)
-{
-double dummy;
-
-/****************************
- * convert to range ]-1,+1[ *
- ****************************/
-
-u[0] = modf (u[0], &dummy);
-u[1] = modf (u[1], &dummy);
-u[2] = modf (u[2], &dummy);
-}
-
-static void static_range_half (double *u)
-{
-/********************************
- * convert to range ]-0.5,+0.5[ *
- ********************************/
-
-if (u[0] < -0.5) u[0] += 1.0;
-if (u[0] > +0.5) u[0] -= 1.0;
-
-if (u[1] < -0.5) u[1] += 1.0;
-if (u[1] > +0.5) u[1] -= 1.0;
-
-if (u[2] < -0.5) u[2] += 1.0;
-if (u[2] > +0.5) u[2] -= 1.0;
-}
-
-static void static_range_positive (double *u)
-{
-/****************************
- * convert to range [0, +1[ *
- ****************************/
-
-if (u[0] < 0.0) u[0] += 1.0;
-if (u[1] < 0.0) u[1] += 1.0;
-if (u[2] < 0.0) u[2] += 1.0;
-}
-
 static void static_wigner_min (gamgi_cell *cell, 
 double *absolute, int *equal, int *node_min)
 {
@@ -207,6 +167,35 @@ for (k = 0; k <= 1; k++)
 return replicas;
 }
 
+static void static_shift (gamgi_cell *cell, int n_positions,
+double *positions, double *translation, double *rotation)
+{
+double position[3];
+int i;
+
+/***************************************************
+ * shift coordinates: first rotate, then translate *
+ *                                                 *
+ * inicial coordinates are in the range ]-1, +1[,  *
+ * this range does not change with rotation, so    *
+ * no need to correct (which is good, because      *
+ * there is no easy correction for translations)   *
+ *                                                 *
+ * the range does change with translation, but     *
+ * in this case a easy correction exists, just     *
+ * apply periodic boundary conditions, reducing    *
+ * the new coordinates to the range ]-1, +1[       *
+ ***************************************************/
+
+for (i = 0; i < n_positions; i++)
+  {
+  gamgi_math_matrix_vector (rotation, positions, position);
+  gamgi_math_vector_add (position, translation, positions);
+  gamgi_math_vector_fmod (positions, positions);
+  positions += 3;
+  }
+}
+
 static void static_conventional (gamgi_cell *cell,
 gamgi_enum vectors, double *xyz)
 {
@@ -253,7 +242,7 @@ if (vectors != GAMGI_PHYS_CONVENTIONAL)
    * use coordinates in the range ]-1, +1[ *
    *****************************************/
 
-  static_range_one (xyz);
+  gamgi_math_vector_fmod (xyz, xyz);
   }
 }
 
@@ -288,7 +277,7 @@ for (n = 0; n < n_positions; n++)
    * use coordinates in the range ]-1, +1[ *
    *****************************************/
 
-  static_range_one (relative);
+  gamgi_math_vector_fmod (relative, relative);
 
   relative += 3;
   }
@@ -333,9 +322,9 @@ for (n = 0; n < n_positions; n++)
    *****************************************************************/
 
   if (cell->type == GAMGI_PHYS_WIGNER)
-    static_range_positive (relative + 3*n);
+    gamgi_math_cell_range_positive (relative + 3*n, relative + 3*n);
   else
-    static_range_half (relative + 3*n);
+    gamgi_math_cell_range_half (relative + 3*n, relative + 3*n);
 
   /*********************************************
    * absolute is the vector that will be added *
@@ -2154,11 +2143,12 @@ free (nodes);
 if (cutoff == GAMGI_PHYS_CUTOFF_OBJECTS) free (points);
 }
 
-void gamgi_phys_cell_link (gamgi_cell *cell, gamgi_atom *atom,
-gamgi_enum vectors, const char **wyckoff, const int *driver,
-int site, double *xyz, gamgi_enum cutoff, int nodes_P, int nodes_I,
-int nodes_A, int nodes_B, int nodes_C, int nodes_R, const char *rule_a,
-const char *rule_b, const char *rule_c, gamgi_window *window)
+void gamgi_phys_cell_link (gamgi_cell *cell, gamgi_atom *atom, 
+gamgi_enum vectors, const char **wyckoff, const int *driver, int site,
+double *xyz, double *translation, double *rotation, gamgi_enum cutoff,
+int nodes_P, int nodes_I, int nodes_A, int nodes_B, int nodes_C,
+int nodes_R, const char *rule_a, const char *rule_b, const char *rule_c,
+gamgi_window *window)
 {
 char pattern_a[GAMGI_ENGINE_STRING];
 char pattern_b[GAMGI_ENGINE_STRING];
@@ -2185,6 +2175,8 @@ strcpy (pattern_c, rule_c);
  * the range ]-1, +1[ (if the selected option is Basis, the   *
  * array relative contains only one position, equal to xyz)   *
  *                                                            *
+ *   apply rotation,translation shift to Wyckoff positions    *
+ *                                                            *
  *  convert to primitive coordinates, in the range ]-1, +1[   *
  *                                                            *
  *  convert to absolute coordinates, relative to each node    *
@@ -2195,6 +2187,8 @@ static_conventional (cell, vectors, xyz);
 relative = gamgi_phys_space_positions (site, 
 xyz, wyckoff, driver, &n_positions, window);
 
+static_shift (cell, n_positions, relative, translation, rotation);
+
 static_primitive (cell, n_positions, relative);
 absolute = static_absolute (cell, n_positions, relative);
 
